from ..enums.manager import EnumManager as EnumManager
from ..exception.service_exception import ValidError as ValidError
from ..logger.logging_ import logging as logging
from ..schemas.query_request import (
    Condition as Condition,
    Filter as Filter,
    FilterGroup as FilterGroup,
    QueryRequest as QueryRequest,
)
from ..utils.core_utils import CoreUtil as CoreUtil
from .class_scaner import ClassScanner as ClassScanner
from sqlalchemy import ColumnElement as ColumnElement
from typing import Any

class QueryBuilder:
    @classmethod
    def get_condition(
        cls,
        *,
        model_class,
        is_relation: bool,
        field_name: str,
        field_op: str,
        field_val: str | int | float | bool | list | None,
    ): ...
    @staticmethod
    def get_condition_python_value(field, field_type, field_value): ...
    @classmethod
    async def get_relation_where(
        cls, *, relation_class: dict, filter_obj: Filter | list
    ): ...
    @classmethod
    async def get_table_where(
        cls, *, model_class, filter_obj: Filter | list, is_relation: bool = False
    ) -> ColumnElement | None:
        """主表的查询条件"""
    @classmethod
    async def get_query_relation(
        cls, *, model_class, model_name, include_path, query_tags, query_format
    ): ...
    @classmethod
    async def deep_serialize_sqlmodel(
        cls,
        obj: Any,
        *,
        response_fields: dict,
        is_tree_node,
        relation_fields: dict | None = None,
        tag_name=None,
    ) -> Any: ...
    @classmethod
    def build_children_tree(cls, flat_list): ...
    @classmethod
    def sqlmodel_format_datetime(cls, value): ...
    @classmethod
    def get_fields(
        cls, *, model_class, relation_class, response_class, query_request: QueryRequest
    ): ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/10/22 下午9:25
# @Desc     ：

from fastapi import Path
from sqlmodel.ext.asyncio.session import AsyncSession

from shudaodao_auth import AuthRouter
from shudaodao_core import Depends, ResponseUtil
from ..meta_config import MetaConfig
from ..schema.enum import EnumQueryRequest
from ..tools.enum_query import EnumQuery

Meta_Enum_Router = AuthRouter(
    prefix=f"/{MetaConfig.RouterPath}/enums",
    tags=["元数据管理 - 字典枚举"],
    db_config_name=MetaConfig.EngineName,  # 配置文件中的数据库连接名称
)


@Meta_Enum_Router.post(path="/{schema_name}/fields", summary=["获取schema下所有枚举字段"])
async def query_schema(
        schema_name: str = Path(description="模式名称"),
        db: AsyncSession = Depends(Meta_Enum_Router.get_async_session)
):
    query_result = await EnumQuery.query_schema(
        db=db, schema_name=schema_name
    )
    return ResponseUtil.success(message="查询成功", data=query_result)


@Meta_Enum_Router.post(path="/{schema_name}/values", summary=["获取schema下指定单个或多个字段的枚举值"])
async def query_field(
        quest_request: EnumQueryRequest, schema_name: str = Path(description="模式名称"),
        db: AsyncSession = Depends(Meta_Enum_Router.get_async_session)
):
    query_result = await EnumQuery.query_field(
        db=db, schema_name=schema_name, quest_request=quest_request
    )
    return ResponseUtil.success(message="查询成功", data=query_result)



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：Shudaodao Auto Generator
# @Software ：PyCharm
# @Desc     ：SQLModel classes for shudaodao_acm.sys_staff

from datetime import datetime, date
from typing import Optional, TYPE_CHECKING

from sqlalchemy import BigInteger

from shudaodao_core import SQLModel, BaseResponse, Field, Relationship, get_primary_id
from ...meta_config import MetaConfig

if TYPE_CHECKING:
    from .sys_department import Department
    from .sys_staff_role import StaffRole


class Staff(MetaConfig.RegistryModel, table=True):
    """数据库对象模型"""

    __tablename__ = "sys_staff"
    __table_args__ = {"schema": MetaConfig.SchemaTable, "comment": "人员表"}
    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理

    staff_id: int = Field(
        default_factory=get_primary_id, primary_key=True, sa_type=BigInteger, description="人员内码"
    )
    department_id: int = Field(
        foreign_key=f"{MetaConfig.SchemaForeignKey}sys_department.department_id",
        sa_type=BigInteger,
        description="部门ID",
    )
    username: str = Field(max_length=100, description="登录账户")
    name: str = Field(max_length=100, description="姓名")
    number: Optional[str] = Field(default=None, nullable=True, max_length=50, description="工号")
    id_number: Optional[str] = Field(default=None, nullable=True, max_length=18, description="身份证号")
    gender: Optional[int] = Field(default=None, nullable=True, description="性别")
    birthday: Optional[date] = Field(default=None, nullable=True, description="出生日期")
    mobile: Optional[str] = Field(default=None, nullable=True, max_length=50, description="手机号码")
    email: Optional[str] = Field(default=None, nullable=True, max_length=100, description="邮箱")
    address: Optional[str] = Field(default=None, nullable=True, max_length=200, description="地址")
    status: Optional[int] = Field(default=None, nullable=True, description="人员状态")
    entry_date: Optional[date] = Field(default=None, nullable=True, description="入职日期")
    leave_date: Optional[date] = Field(default=None, nullable=True, description="离职日期")
    sort_order: Optional[int] = Field(default=None, nullable=True, description="排序权重")
    description: Optional[str] = Field(default=None, nullable=True, max_length=500, description="描述")
    create_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="创建人")
    create_at: Optional[datetime] = Field(default=None, nullable=True, description="创建日期")
    update_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="修改人")
    update_at: Optional[datetime] = Field(default=None, nullable=True, description="修改日期")
    tenant_id: Optional[int] = Field(default=None, sa_type=BigInteger, nullable=True, description="租户内码")
    # 反向关系 - 父对象
    Department: "Department" = Relationship(back_populates="Staffs")
    # 正向关系 - 子对象
    StaffRoles: list["StaffRole"] = Relationship(back_populates="Staff")


class StaffCreate(SQLModel):
    """前端创建模型 - 用于接口请求"""

    department_id: int = Field(sa_type=BigInteger, description="部门ID")
    username: str = Field(max_length=100, description="登录账户")
    name: str = Field(max_length=100, description="姓名")
    number: Optional[str] = Field(default=None, max_length=50, description="工号")
    id_number: Optional[str] = Field(default=None, max_length=18, description="身份证号")
    gender: Optional[int] = Field(default=None, description="性别")
    birthday: Optional[date] = Field(default=None, description="出生日期")
    mobile: Optional[str] = Field(default=None, max_length=50, description="手机号码")
    email: Optional[str] = Field(default=None, max_length=100, description="邮箱")
    address: Optional[str] = Field(default=None, max_length=200, description="地址")
    status: Optional[int] = Field(default=None, description="人员状态")
    entry_date: Optional[date] = Field(default=None, description="入职日期")
    leave_date: Optional[date] = Field(default=None, description="离职日期")
    sort_order: Optional[int] = Field(default=None, description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class StaffUpdate(SQLModel):
    """前端更新模型 - 用于接口请求"""

    staff_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="人员内码")
    department_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="部门ID")
    username: Optional[str] = Field(default=None, max_length=100, description="登录账户")
    name: Optional[str] = Field(default=None, max_length=100, description="姓名")
    number: Optional[str] = Field(default=None, max_length=50, description="工号")
    id_number: Optional[str] = Field(default=None, max_length=18, description="身份证号")
    gender: Optional[int] = Field(default=None, description="性别")
    birthday: Optional[date] = Field(default=None, description="出生日期")
    mobile: Optional[str] = Field(default=None, max_length=50, description="手机号码")
    email: Optional[str] = Field(default=None, max_length=100, description="邮箱")
    address: Optional[str] = Field(default=None, max_length=200, description="地址")
    status: Optional[int] = Field(default=None, description="人员状态")
    entry_date: Optional[date] = Field(default=None, description="入职日期")
    leave_date: Optional[date] = Field(default=None, description="离职日期")
    sort_order: Optional[int] = Field(default=None, description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class StaffResponse(BaseResponse):
    """前端响应模型 - 用于接口响应"""

    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
    staff_id: int = Field(description="人员内码", sa_type=BigInteger)
    department_id: int = Field(description="部门ID", sa_type=BigInteger)
    username: str = Field(description="登录账户")
    name: str = Field(description="姓名")
    number: Optional[str] = Field(description="工号", default=None)
    id_number: Optional[str] = Field(description="身份证号", default=None)
    gender: Optional[int] = Field(description="性别", default=None)
    birthday: Optional[date] = Field(description="出生日期", default=None)
    mobile: Optional[str] = Field(description="手机号码", default=None)
    email: Optional[str] = Field(description="邮箱", default=None)
    address: Optional[str] = Field(description="地址", default=None)
    status: Optional[int] = Field(description="人员状态", default=None)
    entry_date: Optional[date] = Field(description="入职日期", default=None)
    leave_date: Optional[date] = Field(description="离职日期", default=None)
    sort_order: Optional[int] = Field(description="排序权重", default=None)
    description: Optional[str] = Field(description="描述", default=None)
    create_by: Optional[str] = Field(description="创建人", default=None)
    create_at: Optional[datetime] = Field(description="创建日期", default=None)
    update_by: Optional[str] = Field(description="修改人", default=None)
    update_at: Optional[datetime] = Field(description="修改日期", default=None)



from _typeshed import Incomplete
from shudaodao_core.type.var import (
    SQLModelCreate as SQLModelCreate,
    SQLModelDB as SQLModelDB,
    SQLModelResponse as SQLModelResponse,
    SQLModelUpdate as SQLModelUpdate,
)

class EntityClass:
    schema_name: Incomplete
    class_name: Incomplete
    engine_name: Incomplete
    model_class: None
    create_class: None
    update_class: None
    response_class: None
    module_name: Incomplete
    def __init__(
        self,
        *,
        schema_name: str = None,
        entity_name: str,
        engine_name: str = None,
        module_name: str = None,
    ) -> None: ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/11/13 上午11:41
# @Desc     ：


from datetime import datetime
from typing import Optional

from pydantic import EmailStr
from sqlalchemy import BigInteger, Boolean

from shudaodao_core import SQLModel, BaseResponse, Field, get_primary_id
from ..meta_config import MetaConfig


class AuthUser(MetaConfig.RegistryModel, table=True):
    """数据库对象模型"""

    __tablename__ = "t_auth_user"
    __table_args__ = {"schema": MetaConfig.SchemaTable, "comment": "鉴权账户"}
    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理

    user_id: int = Field(
        default_factory=get_primary_id, primary_key=True, sa_type=BigInteger, description="主键"
    )
    username: str = Field(max_length=50, unique=True, index=True, description="账户名")
    name: Optional[str] = Field(default=None, nullable=True, description="姓名")
    password: str = Field(description="密码")
    is_active: bool = Field(sa_type=Boolean, description="启用状态")
    last_login_at: Optional[datetime] = Field(default=None, nullable=True, description="最后登录时间")
    nickname: Optional[str] = Field(default=None, nullable=True, description="昵称")
    picture: Optional[str] = Field(default=None, nullable=True, description="头像URL地址")
    email: Optional[str] = Field(default=None, nullable=True, description="邮件")
    email_verified: Optional[bool] = Field(
        default=None, sa_type=Boolean, nullable=True, description="邮箱是否已验证"
    )
    totp_verified: Optional[bool] = Field(
        default=None, sa_type=Boolean, nullable=True, description="启用身份验证器"
    )
    create_by: Optional[str] = Field(default=None, nullable=True, description="创建人")
    create_at: Optional[datetime] = Field(default=None, nullable=True, description="创建日期")
    update_by: Optional[str] = Field(default=None, nullable=True, description="修改人")
    update_at: Optional[datetime] = Field(default=None, nullable=True, description="修改日期")
    tenant_id: Optional[int] = Field(default=None, sa_type=BigInteger, nullable=True, description="默认租户")
    staff_id: Optional[int] = Field(default=None, sa_type=BigInteger, nullable=True, description="默认用户")


class AuthUserResponse(BaseResponse):
    """前端响应模型 - 用于接口响应"""

    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
    user_id: int = Field(description="主键", sa_type=BigInteger)
    username: str = Field(description="账户名")
    name: Optional[str] = Field(description="姓名", default=None)
    password: str = Field(description="密码")
    is_active: bool = Field(description="启用状态")
    last_login_at: Optional[datetime] = Field(description="最后登录时间", default=None)
    nickname: Optional[str] = Field(description="昵称", default=None)
    picture: Optional[str] = Field(description="头像URL地址", default=None)
    email: Optional[str] = Field(description="邮件", default=None)
    email_verified: Optional[bool] = Field(description="邮箱是否已验证", default=None)
    totp_verified: Optional[bool] = Field(description="启用身份验证器", default=None)
    create_by: Optional[str] = Field(description="创建人", default=None)
    create_at: Optional[datetime] = Field(description="创建日期", default=None)
    update_by: Optional[str] = Field(description="修改人", default=None)
    update_at: Optional[datetime] = Field(description="修改日期", default=None)
    staff_id: Optional[int] = Field(description="默认用户", default=None, sa_type=BigInteger)


class AuthUserRegister(SQLModel):
    """ 注册模型 """
    username: str = Field(min_length=5, max_length=50)
    password: str = Field(min_length=5)
    # --- 核心字段 ---
    name: str = Field(default=None, nullable=True, description="姓名")
    last_login_at: Optional[datetime] = Field(default_factory=lambda: datetime.now(), description="最后登录时间")
    # --- 可修改字段 ---
    nickname: str = Field(default=None, nullable=True, description="昵称")
    picture: Optional[str] = Field(default=None, nullable=True, description="头像URL地址")
    email: Optional[EmailStr] = Field(default=None, nullable=True, description="邮件")
    # --- 用户验证增强 ---
    # email_verified: Optional[bool] = Field(default=None, nullable=True, description="邮箱是否已验证")
    # --- 内部管理字段 ---
    tenant_id: Optional[int] = Field(default=None, nullable=True, sa_type=BigInteger, description="默认租户")


class AuthLogin(SQLModel):
    """ 登录模型 """
    username: str = Field(min_length=3, max_length=50)
    password: str = Field(min_length=5)


class AuthPassword(SQLModel):
    """ 修改密码模型 """
    old_password: str
    new_password: str = Field(min_length=6, max_length=50)



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：Shudaodao Auto Generator
# @Software ：PyCharm
# @Desc     ：SQLModel classes for shudaodao_meta.source_table

from datetime import datetime
from typing import Optional, TYPE_CHECKING

from sqlalchemy import BigInteger, Text

from shudaodao_core import SQLModel, BaseResponse, Field, Relationship, get_primary_id
from ...meta_config import MetaConfig

if TYPE_CHECKING:
    from .source_column import SourceColumn
    from .source_foreign_key import SourceForeignKey
    from .source_index import SourceIndex
    from .source_primary_key import SourcePrimaryKey
    from .source_referencing_foreign_key import SourceReferencingForeignKey
    from .source_schema import SourceSchema


class SourceTable(MetaConfig.RegistryModel, table=True):
    """数据库对象模型"""

    __tablename__ = "source_table"
    __table_args__ = {"schema": MetaConfig.SchemaTable, "comment": "表元数据"}
    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理

    source_table_id: int = Field(
        default_factory=get_primary_id, primary_key=True, sa_type=BigInteger, description="主键"
    )
    source_schema_id: int = Field(
        foreign_key=f"{MetaConfig.SchemaForeignKey}source_schema.source_schema_id",
        ondelete="CASCADE",
        sa_type=BigInteger,
        description="外键-模式(schema)",
    )
    table_name: str = Field(max_length=255, description="表名字")
    comment: Optional[str] = Field(default=None, sa_type=Text, nullable=True, description="备注")
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(default=None, nullable=True, max_length=500, description="描述")
    create_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="创建人")
    create_at: Optional[datetime] = Field(default=None, nullable=True, description="创建日期")
    update_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="修改人")
    update_at: Optional[datetime] = Field(default=None, nullable=True, description="修改日期")
    # 反向关系 - 父对象
    SourceSchema: "SourceSchema" = Relationship(back_populates="SourceTables")
    # 正向关系 - 子对象
    SourceColumns: list["SourceColumn"] = Relationship(
        back_populates="SourceTable", sa_relationship_kwargs={"order_by": "SourceColumn.sort_order.asc()"}
    )
    # 正向关系 - 子对象
    SourceForeignKeys: list["SourceForeignKey"] = Relationship(
        back_populates="SourceTable", sa_relationship_kwargs={"order_by": "SourceForeignKey.sort_order.asc()"}
    )
    # 正向关系 - 子对象
    SourceIndexes: list["SourceIndex"] = Relationship(
        back_populates="SourceTable", sa_relationship_kwargs={"order_by": "SourceIndex.sort_order.asc()"}
    )
    # 正向关系 - 子对象
    SourcePrimaryKey: "SourcePrimaryKey" = Relationship(back_populates="SourceTable")
    # 正向关系 - 子对象
    SourceReferencingForeignKeys: list["SourceReferencingForeignKey"] = Relationship(
        back_populates="SourceTable",
        sa_relationship_kwargs={"order_by": "SourceReferencingForeignKey.sort_order.asc()"},
    )


class SourceTableCreate(SQLModel):
    """前端创建模型 - 用于接口请求"""

    source_schema_id: int = Field(sa_type=BigInteger, description="外键-模式(schema)")
    table_name: str = Field(max_length=255, description="表名字")
    comment: Optional[str] = Field(default=None, description="备注")
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class SourceTableUpdate(SQLModel):
    """前端更新模型 - 用于接口请求"""

    source_table_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="主键")
    source_schema_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="外键-模式(schema)")
    table_name: Optional[str] = Field(default=None, max_length=255, description="表名字")
    comment: Optional[str] = Field(default=None, description="备注")
    sort_order: Optional[int] = Field(default=None, description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class SourceTableResponse(BaseResponse):
    """前端响应模型 - 用于接口响应"""

    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
    source_table_id: int = Field(description="主键", sa_type=BigInteger)
    source_schema_id: int = Field(description="外键-模式(schema)", sa_type=BigInteger)
    table_name: str = Field(description="表名字")
    comment: Optional[str] = Field(description="备注", default=None)
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(description="描述", default=None)
    create_by: Optional[str] = Field(description="创建人", default=None)
    create_at: Optional[datetime] = Field(description="创建日期", default=None)
    update_by: Optional[str] = Field(description="修改人", default=None)
    update_at: Optional[datetime] = Field(description="修改日期", default=None)



from .checker import check_admin_user as check_admin_user
from .engine import load_engine as load_engine, unload_engine as unload_engine
from .fast_api import create_init_fastapi as create_init_fastapi
from .meta import load_meta_config as load_meta_config
from _typeshed import Incomplete
from fastapi import FastAPI as FastAPI
from typing import Callable

class Application:
    """应用核心类，负责初始化和管理FastAPI应用"""

    fastapi: Incomplete
    def __init__(self) -> None:
        """初始化应用核心组件"""
    def run(self) -> None: ...
    def startup(self, func: Callable):
        """装饰器或直接注册启动回调"""



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：Shudaodao Auto Generator
# @Software ：PyCharm
# @Desc     ：SQLModel classes for shudaodao_acm.sys_role

from datetime import datetime
from typing import Optional, TYPE_CHECKING

from sqlalchemy import BigInteger, Boolean

from shudaodao_core import SQLModel, BaseResponse, Field, Relationship, get_primary_id
from ...meta_config import MetaConfig

if TYPE_CHECKING:
    from .sys_system import System


class Role(MetaConfig.RegistryModel, table=True):
    """数据库对象模型"""

    __tablename__ = "sys_role"
    __table_args__ = {"schema": MetaConfig.SchemaTable}
    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理

    role_id: int = Field(
        default_factory=get_primary_id, primary_key=True, sa_type=BigInteger, description="角色内码"
    )
    system_id: int = Field(
        foreign_key=f"{MetaConfig.SchemaForeignKey}sys_system.system_id",
        sa_type=BigInteger,
        description="系统内码",
    )
    role_pid: int = Field(sa_type=BigInteger, description="上级角色")
    role_name: Optional[str] = Field(default=None, nullable=True, max_length=100, description="角色名称")
    role_code: Optional[str] = Field(default=None, nullable=True, max_length=100, description="角色编码")
    role_type: str = Field(max_length=50, description="角色类型")
    is_active: bool = Field(sa_type=Boolean, description="启用状态")
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(default=None, nullable=True, max_length=500, description="描述")
    create_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="创建人")
    create_at: Optional[datetime] = Field(default=None, nullable=True, description="创建日期")
    update_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="修改人")
    update_at: Optional[datetime] = Field(default=None, nullable=True, description="修改日期")
    tenant_id: Optional[int] = Field(default=None, sa_type=BigInteger, nullable=True, description="租户内码")
    # 反向关系 - 父对象
    System: "System" = Relationship(back_populates="Roles")


class RoleCreate(SQLModel):
    """前端创建模型 - 用于接口请求"""

    system_id: int = Field(sa_type=BigInteger, description="系统内码")
    role_pid: int = Field(sa_type=BigInteger, description="上级角色")
    role_name: Optional[str] = Field(default=None, max_length=100, description="角色名称")
    role_code: Optional[str] = Field(default=None, max_length=100, description="角色编码")
    role_type: str = Field(max_length=50, description="角色类型")
    is_active: bool = Field(description="启用状态")
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class RoleUpdate(SQLModel):
    """前端更新模型 - 用于接口请求"""

    role_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="角色内码")
    system_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="系统内码")
    role_pid: Optional[int] = Field(default=None, sa_type=BigInteger, description="上级角色")
    role_name: Optional[str] = Field(default=None, max_length=100, description="角色名称")
    role_code: Optional[str] = Field(default=None, max_length=100, description="角色编码")
    role_type: Optional[str] = Field(default=None, max_length=50, description="角色类型")
    is_active: Optional[bool] = Field(default=None, description="启用状态")
    sort_order: Optional[int] = Field(default=None, description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class RoleResponse(BaseResponse):
    """前端响应模型 - 用于接口响应"""

    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
    role_id: int = Field(description="角色内码", sa_type=BigInteger)
    system_id: int = Field(description="系统内码", sa_type=BigInteger)
    role_pid: int = Field(description="上级角色", sa_type=BigInteger)
    role_name: Optional[str] = Field(description="角色名称", default=None)
    role_code: Optional[str] = Field(description="角色编码", default=None)
    role_type: str = Field(description="角色类型")
    is_active: bool = Field(description="启用状态")
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(description="描述", default=None)
    create_by: Optional[str] = Field(description="创建人", default=None)
    create_at: Optional[datetime] = Field(description="创建日期", default=None)
    update_by: Optional[str] = Field(description="修改人", default=None)
    update_at: Optional[datetime] = Field(description="修改日期", default=None)



def load_engine() -> None:
    """初始化底层引擎组件。

    包括：
    - RedisEngine：Redis连接池
    - DatabaseEngine：SQLAlchemy异步引擎
    - DiskEngine：本地磁盘存储
    - PermissionEngine：Casbin权限引擎
    """

async def unload_engine() -> None: ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：Shudaodao Auto Generator
# @Software ：PyCharm
# @Desc     ：SQLModel classes for shudaodao_meta.source_referencing_foreign_key

from datetime import datetime
from typing import Optional, TYPE_CHECKING

from sqlalchemy import BigInteger, Boolean, Text

from shudaodao_core import SQLModel, BaseResponse, Field, Relationship, get_primary_id
from ...meta_config import MetaConfig

if TYPE_CHECKING:
    from .source_foreign_key import SourceForeignKey
    from .source_schema import SourceSchema
    from .source_table import SourceTable


class SourceReferencingForeignKey(MetaConfig.RegistryModel, table=True):
    """数据库对象模型"""

    __tablename__ = "source_referencing_foreign_key"
    __table_args__ = {"schema": MetaConfig.SchemaTable, "comment": "引用当前表的外键"}
    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理

    source_referencing_foreign_key_id: int = Field(
        default_factory=get_primary_id, primary_key=True, sa_type=BigInteger, description="主键"
    )
    source_schema_id: int = Field(
        foreign_key=f"{MetaConfig.SchemaForeignKey}source_schema.source_schema_id",
        ondelete="CASCADE",
        sa_type=BigInteger,
        description="数据库模式",
    )
    source_foreign_key_id: int = Field(
        foreign_key=f"{MetaConfig.SchemaForeignKey}source_foreign_key.source_foreign_key_id",
        ondelete="CASCADE",
        sa_type=BigInteger,
        description="主键",
    )
    source_table_id: int = Field(
        foreign_key=f"{MetaConfig.SchemaForeignKey}source_table.source_table_id",
        ondelete="CASCADE",
        sa_type=BigInteger,
        description="表",
    )
    name: Optional[str] = Field(default=None, nullable=True, max_length=255, description="约束名称")
    unique: bool = Field(sa_type=Boolean, description="是否唯一")
    constrained_schema: Optional[str] = Field(
        default=None, nullable=True, max_length=128, description="当前架构"
    )
    constrained_table: Optional[str] = Field(
        default=None, nullable=True, max_length=255, description="当前表"
    )
    constrained_columns: str = Field(max_length=255, description="当前字段集合")
    referred_schema: Optional[str] = Field(
        default=None, nullable=True, max_length=128, description="引用架构"
    )
    referred_table: str = Field(max_length=255, description="引用表")
    referred_columns: Optional[str] = Field(
        default=None, sa_type=Text, nullable=True, description="引用字段集合"
    )
    referred_orderby: Optional[bool] = Field(
        default=None, sa_type=Boolean, nullable=True, description="包含排序字段"
    )
    options: Optional[str] = Field(default=None, nullable=True, max_length=255, description="行为选项")
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(default=None, nullable=True, max_length=500, description="描述")
    create_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="创建人")
    create_at: Optional[datetime] = Field(default=None, nullable=True, description="创建日期")
    update_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="修改人")
    update_at: Optional[datetime] = Field(default=None, nullable=True, description="修改日期")
    # 反向关系 - 父对象
    SourceForeignKey: "SourceForeignKey" = Relationship(back_populates="SourceReferencingForeignKeys")
    # 反向关系 - 父对象
    SourceSchema: "SourceSchema" = Relationship(back_populates="SourceReferencingForeignKeys")
    # 反向关系 - 父对象
    SourceTable: "SourceTable" = Relationship(back_populates="SourceReferencingForeignKeys")


class SourceReferencingForeignKeyCreate(SQLModel):
    """前端创建模型 - 用于接口请求"""

    source_schema_id: int = Field(sa_type=BigInteger, description="数据库模式")
    source_foreign_key_id: int = Field(sa_type=BigInteger, description="主键")
    source_table_id: int = Field(sa_type=BigInteger, description="表")
    name: Optional[str] = Field(default=None, max_length=255, description="约束名称")
    unique: bool = Field(description="是否唯一")
    constrained_schema: Optional[str] = Field(default=None, max_length=128, description="当前架构")
    constrained_table: Optional[str] = Field(default=None, max_length=255, description="当前表")
    constrained_columns: str = Field(max_length=255, description="当前字段集合")
    referred_schema: Optional[str] = Field(default=None, max_length=128, description="引用架构")
    referred_table: str = Field(max_length=255, description="引用表")
    referred_columns: Optional[str] = Field(default=None, description="引用字段集合")
    referred_orderby: Optional[bool] = Field(default=None, description="包含排序字段")
    options: Optional[str] = Field(default=None, max_length=255, description="行为选项")
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class SourceReferencingForeignKeyUpdate(SQLModel):
    """前端更新模型 - 用于接口请求"""

    source_referencing_foreign_key_id: Optional[int] = Field(
        default=None, sa_type=BigInteger, description="主键"
    )
    source_schema_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="数据库模式")
    source_foreign_key_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="主键")
    source_table_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="表")
    name: Optional[str] = Field(default=None, max_length=255, description="约束名称")
    unique: Optional[bool] = Field(default=None, description="是否唯一")
    constrained_schema: Optional[str] = Field(default=None, max_length=128, description="当前架构")
    constrained_table: Optional[str] = Field(default=None, max_length=255, description="当前表")
    constrained_columns: Optional[str] = Field(default=None, max_length=255, description="当前字段集合")
    referred_schema: Optional[str] = Field(default=None, max_length=128, description="引用架构")
    referred_table: Optional[str] = Field(default=None, max_length=255, description="引用表")
    referred_columns: Optional[str] = Field(default=None, description="引用字段集合")
    referred_orderby: Optional[bool] = Field(default=None, description="包含排序字段")
    options: Optional[str] = Field(default=None, max_length=255, description="行为选项")
    sort_order: Optional[int] = Field(default=None, description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class SourceReferencingForeignKeyResponse(BaseResponse):
    """前端响应模型 - 用于接口响应"""

    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
    source_referencing_foreign_key_id: int = Field(description="主键", sa_type=BigInteger)
    source_schema_id: int = Field(description="数据库模式", sa_type=BigInteger)
    source_foreign_key_id: int = Field(description="主键", sa_type=BigInteger)
    source_table_id: int = Field(description="表", sa_type=BigInteger)
    name: Optional[str] = Field(description="约束名称", default=None)
    unique: bool = Field(description="是否唯一")
    constrained_schema: Optional[str] = Field(description="当前架构", default=None)
    constrained_table: Optional[str] = Field(description="当前表", default=None)
    constrained_columns: str = Field(description="当前字段集合")
    referred_schema: Optional[str] = Field(description="引用架构", default=None)
    referred_table: str = Field(description="引用表")
    referred_columns: Optional[str] = Field(description="引用字段集合", default=None)
    referred_orderby: Optional[bool] = Field(description="包含排序字段", default=None)
    options: Optional[str] = Field(description="行为选项", default=None)
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(description="描述", default=None)
    create_by: Optional[str] = Field(description="创建人", default=None)
    create_at: Optional[datetime] = Field(description="创建日期", default=None)
    update_by: Optional[str] = Field(description="修改人", default=None)
    update_at: Optional[datetime] = Field(description="修改日期", default=None)



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：Shudaodao Auto Generator
# @Software ：PyCharm
# @Desc     ：SQLModel classes for shudaodao_meta.t_test_parent

from typing import Optional

from sqlalchemy import PrimaryKeyConstraint

from shudaodao_core import SQLModel, BaseResponse, Field, get_primary_id
from ...meta_config import MetaConfig


class TestParent(MetaConfig.RegistryModel, table=True):
    """数据库对象模型"""

    __tablename__ = "t_test_parent"
    __table_args__ = (
        PrimaryKeyConstraint("test_parent_id", "meta_schema_id"),
        {"schema": MetaConfig.SchemaTable},
    )
    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理

    test_parent_id: int = Field(default_factory=get_primary_id, primary_key=True)
    meta_schema_id: int = Field(default_factory=get_primary_id, primary_key=True)
    test_parent_name: Optional[int] = Field(default=None, nullable=True)


class TestParentCreate(SQLModel):
    """前端创建模型 - 用于接口请求"""

    test_parent_name: Optional[int] = Field(default=None)


class TestParentUpdate(SQLModel):
    """前端更新模型 - 用于接口请求"""

    test_parent_id: Optional[int] = Field(default=None)
    meta_schema_id: Optional[int] = Field(default=None)
    test_parent_name: Optional[int] = Field(default=None)


class TestParentResponse(BaseResponse):
    """前端响应模型 - 用于接口响应"""

    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
    test_parent_id: int = Field()
    meta_schema_id: int = Field()
    test_parent_name: Optional[int] = Field(default=None)



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/9/2 下午4:11
# @Desc     ：

from fastapi import Depends

from shudaodao_auth import AuthRouter, AuthService
from shudaodao_auth.entity_table.t_auth_user import AuthUserResponse
from shudaodao_auth.meta_config import MetaConfig as AuthMetaConfig
from shudaodao_core import ResponseUtil
from ..meta_config import MetaConfig

Auth_Controller = AuthRouter(
    prefix=f"/{AuthMetaConfig.RouterPath}",
    tags=AuthMetaConfig.RouterTags,
    db_config_name=MetaConfig.EngineName,
)


# 受保护的路由
@Auth_Controller.get("/me", summary="当前用户信息")
async def auth_me(
        current_user: AuthUserResponse = Depends(AuthService.get_current_user)
):
    # return ResponseUtil.success(
    #     message="获取用户信息成功",
    #     data=current_user
    # )
    result_data = current_user.__dict__
    result_data.update({
        "desc": "-------------------以下非数据库字段，满足Art Design Pro临时登录用-------------------",
        "userId": current_user.user_id,
        "userName": current_user.name,
        "roles": ['R_SUPER', 'R_ADMIN', 'R_USER'],
        "buttons": [],
        "email": current_user.email,
        "avatar": ""
    })
    return ResponseUtil.success(
        message="获取用户信息成功",
        data=result_data
    )



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：Shudaodao Auto Generator
# @Software ：PyCharm
# @Desc     ：SQLModel classes for shudaodao_meta.meta_constraint

from datetime import datetime
from typing import Optional, TYPE_CHECKING

from sqlalchemy import BigInteger, Boolean

from shudaodao_core import SQLModel, BaseResponse, Field, Relationship, get_primary_id
from ...meta_config import MetaConfig

if TYPE_CHECKING:
    from .meta_table import MetaTable


class MetaConstraint(MetaConfig.RegistryModel, table=True):
    """数据库对象模型"""

    __tablename__ = "meta_constraint"
    __table_args__ = {"schema": MetaConfig.SchemaTable, "comment": "表约束元数据"}
    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理

    meta_constraint_id: int = Field(
        default_factory=get_primary_id, primary_key=True, sa_type=BigInteger, description="主键"
    )
    meta_table_id: int = Field(
        foreign_key=f"{MetaConfig.SchemaForeignKey}meta_table.meta_table_id",
        ondelete="CASCADE",
        sa_type=BigInteger,
        description="外键-表",
    )
    constr_type: str = Field(max_length=255, description="约束类型")
    constr_name: Optional[str] = Field(default=None, nullable=True, max_length=255, description="约束名称")
    constr_unique: Optional[bool] = Field(
        default=None, sa_type=Boolean, nullable=True, description="是否唯一"
    )
    constr_direction: Optional[str] = Field(
        default=None, nullable=True, max_length=255, description="正向关系(子)、反向关系(父)"
    )
    constr_schema: Optional[str] = Field(
        default=None, nullable=True, max_length=255, description="当前对象 - 模式"
    )
    constr_table: Optional[str] = Field(
        default=None, nullable=True, max_length=255, description="当前对象 - 表"
    )
    constr_columns: str = Field(max_length=255, description="当前对象 - 列")
    constr_index: Optional[str] = Field(
        default=None, nullable=True, max_length=255, description="当前对象 - 索引"
    )
    constr_field: Optional[str] = Field(
        default=None, nullable=True, max_length=255, description="当前对象 - 字段"
    )
    constr_class: Optional[str] = Field(
        default=None, nullable=True, max_length=255, description="当前对象 - 类"
    )
    relationship_field: Optional[str] = Field(
        default=None, nullable=True, max_length=255, description="关系字段"
    )
    relationship_orderby: Optional[str] = Field(
        default=None, nullable=True, max_length=255, description="关系列表的排序字段"
    )
    constr_options: Optional[str] = Field(default=None, nullable=True, max_length=255, description="行为选项")
    referred_schema: Optional[str] = Field(
        default=None, nullable=True, max_length=255, description="引用对象 - 模式"
    )
    referred_table: Optional[str] = Field(
        default=None, nullable=True, max_length=255, description="引用对象 - 表"
    )
    referred_columns: Optional[str] = Field(
        default=None, nullable=True, max_length=255, description="引用对象 - 列"
    )
    referred_index: Optional[str] = Field(
        default=None, nullable=True, max_length=255, description="引用对象 - 索引"
    )
    is_active: bool = Field(sa_type=Boolean, description="启用状态")
    sort_order: Optional[int] = Field(default=None, nullable=True, description="排序权重")
    description: Optional[str] = Field(default=None, nullable=True, max_length=500, description="描述")
    create_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="创建人")
    create_at: Optional[datetime] = Field(default=None, nullable=True, description="创建日期")
    update_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="修改人")
    update_at: Optional[datetime] = Field(default=None, nullable=True, description="修改日期")
    # 反向关系 - 父对象
    MetaTable: "MetaTable" = Relationship(back_populates="MetaConstraints")


class MetaConstraintCreate(SQLModel):
    """前端创建模型 - 用于接口请求"""

    meta_table_id: int = Field(sa_type=BigInteger, description="外键-表")
    constr_type: str = Field(max_length=255, description="约束类型")
    constr_name: Optional[str] = Field(default=None, max_length=255, description="约束名称")
    constr_unique: Optional[bool] = Field(default=None, description="是否唯一")
    constr_direction: Optional[str] = Field(
        default=None, max_length=255, description="正向关系(子)、反向关系(父)"
    )
    constr_schema: Optional[str] = Field(default=None, max_length=255, description="当前对象 - 模式")
    constr_table: Optional[str] = Field(default=None, max_length=255, description="当前对象 - 表")
    constr_columns: str = Field(max_length=255, description="当前对象 - 列")
    constr_index: Optional[str] = Field(default=None, max_length=255, description="当前对象 - 索引")
    constr_field: Optional[str] = Field(default=None, max_length=255, description="当前对象 - 字段")
    constr_class: Optional[str] = Field(default=None, max_length=255, description="当前对象 - 类")
    relationship_field: Optional[str] = Field(default=None, max_length=255, description="关系字段")
    relationship_orderby: Optional[str] = Field(
        default=None, max_length=255, description="关系列表的排序字段"
    )
    constr_options: Optional[str] = Field(default=None, max_length=255, description="行为选项")
    referred_schema: Optional[str] = Field(default=None, max_length=255, description="引用对象 - 模式")
    referred_table: Optional[str] = Field(default=None, max_length=255, description="引用对象 - 表")
    referred_columns: Optional[str] = Field(default=None, max_length=255, description="引用对象 - 列")
    referred_index: Optional[str] = Field(default=None, max_length=255, description="引用对象 - 索引")
    is_active: bool = Field(description="启用状态")
    sort_order: Optional[int] = Field(default=None, description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class MetaConstraintUpdate(SQLModel):
    """前端更新模型 - 用于接口请求"""

    meta_constraint_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="主键")
    meta_table_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="外键-表")
    constr_type: Optional[str] = Field(default=None, max_length=255, description="约束类型")
    constr_name: Optional[str] = Field(default=None, max_length=255, description="约束名称")
    constr_unique: Optional[bool] = Field(default=None, description="是否唯一")
    constr_direction: Optional[str] = Field(
        default=None, max_length=255, description="正向关系(子)、反向关系(父)"
    )
    constr_schema: Optional[str] = Field(default=None, max_length=255, description="当前对象 - 模式")
    constr_table: Optional[str] = Field(default=None, max_length=255, description="当前对象 - 表")
    constr_columns: Optional[str] = Field(default=None, max_length=255, description="当前对象 - 列")
    constr_index: Optional[str] = Field(default=None, max_length=255, description="当前对象 - 索引")
    constr_field: Optional[str] = Field(default=None, max_length=255, description="当前对象 - 字段")
    constr_class: Optional[str] = Field(default=None, max_length=255, description="当前对象 - 类")
    relationship_field: Optional[str] = Field(default=None, max_length=255, description="关系字段")
    relationship_orderby: Optional[str] = Field(
        default=None, max_length=255, description="关系列表的排序字段"
    )
    constr_options: Optional[str] = Field(default=None, max_length=255, description="行为选项")
    referred_schema: Optional[str] = Field(default=None, max_length=255, description="引用对象 - 模式")
    referred_table: Optional[str] = Field(default=None, max_length=255, description="引用对象 - 表")
    referred_columns: Optional[str] = Field(default=None, max_length=255, description="引用对象 - 列")
    referred_index: Optional[str] = Field(default=None, max_length=255, description="引用对象 - 索引")
    is_active: Optional[bool] = Field(default=None, description="启用状态")
    sort_order: Optional[int] = Field(default=None, description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class MetaConstraintResponse(BaseResponse):
    """前端响应模型 - 用于接口响应"""

    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
    meta_constraint_id: int = Field(description="主键", sa_type=BigInteger)
    meta_table_id: int = Field(description="外键-表", sa_type=BigInteger)
    constr_type: str = Field(description="约束类型")
    constr_name: Optional[str] = Field(description="约束名称", default=None)
    constr_unique: Optional[bool] = Field(description="是否唯一", default=None)
    constr_direction: Optional[str] = Field(description="正向关系(子)、反向关系(父)", default=None)
    constr_schema: Optional[str] = Field(description="当前对象 - 模式", default=None)
    constr_table: Optional[str] = Field(description="当前对象 - 表", default=None)
    constr_columns: str = Field(description="当前对象 - 列")
    constr_index: Optional[str] = Field(description="当前对象 - 索引", default=None)
    constr_field: Optional[str] = Field(description="当前对象 - 字段", default=None)
    constr_class: Optional[str] = Field(description="当前对象 - 类", default=None)
    relationship_field: Optional[str] = Field(description="关系字段", default=None)
    relationship_orderby: Optional[str] = Field(description="关系列表的排序字段", default=None)
    constr_options: Optional[str] = Field(description="行为选项", default=None)
    referred_schema: Optional[str] = Field(description="引用对象 - 模式", default=None)
    referred_table: Optional[str] = Field(description="引用对象 - 表", default=None)
    referred_columns: Optional[str] = Field(description="引用对象 - 列", default=None)
    referred_index: Optional[str] = Field(description="引用对象 - 索引", default=None)
    is_active: bool = Field(description="启用状态")
    sort_order: Optional[int] = Field(description="排序权重", default=None)
    description: Optional[str] = Field(description="描述", default=None)
    create_by: Optional[str] = Field(description="创建人", default=None)
    create_at: Optional[datetime] = Field(description="创建日期", default=None)
    update_by: Optional[str] = Field(description="修改人", default=None)
    update_at: Optional[datetime] = Field(description="修改日期", default=None)



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/11/9 下午8:38
# @Desc     ：

from typing import Optional

from fastapi import Path

from shudaodao_auth import AuthRouter
from shudaodao_meta.meta_config import MetaConfig
from ..services.generic_service_v1 import GenericServiceV1

generic_router = AuthRouter(
    prefix=f"/v1",
    db_config_name=MetaConfig.EngineName,
    tags=["通用接口 - 增删改查 v1 - 兼容 java 接口"],
)


@generic_router.post(path="/{schema_path}/{entity_path}", summary="创建 schema - table/view 的数据")
async def create_route(
        create_model: dict,
        schema_path: str = Path(description="数据库模式名称/别名"),
        entity_path: str = Path(description="数据库实体名称/别名"),
):
    return await GenericServiceV1.create(
        schema_path=schema_path, entity_path=entity_path,
        create_models=create_model,
    )


@generic_router.delete(
    path="/{schema_path}/{entity_path}/{primary_id}", summary="获取 schema - table/view 的数据")
async def delete_route(
        primary_id: Optional[int] = Path(description="主键ID值]"),
        schema_path: str = Path(description="数据库模式名称/别名"),
        entity_path: str = Path(description="数据库实体名称/别名"),
):
    return await GenericServiceV1.delete(
        schema_path=schema_path, entity_path=entity_path,
        primary_id=primary_id,
    )


@generic_router.put(
    path="/{schema_path}/{entity_path}/{primary_id}", summary="更新 schema - table/view 的数据")
@generic_router.patch(
    path="/{schema_path}/{entity_path}/{primary_id}", summary="更新 schema - table/view 的数据")
async def update_route(
        update_models: dict,
        primary_id: Optional[int] = Path(description="主键ID值,int或List[int]"),
        schema_path: str = Path(description="数据库模式名称/别名"),
        entity_path: str = Path(description="数据库实体名称/别名"),
):
    return await GenericServiceV1.update(
        schema_path=schema_path, entity_path=entity_path,
        primary_id=primary_id, update_models=update_models
    )


@generic_router.get(
    path="/{schema_path}/{entity_path}/{primary_id}", summary="获取 schema - table/view 的数据")
async def read_route(
        primary_id: Optional[int] = Path(description="主键ID值]"),
        schema_path: str = Path(description="数据库模式名称/别名"),
        entity_path: str = Path(description="数据库实体名称/别名"),
):
    return await GenericServiceV1.read(
        schema_path=schema_path, entity_path=entity_path,
        primary_id=primary_id
    )



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/11/3 上午2:01
# @Desc     ：

from shudaodao_core import AppConfig, CoreUtil
from .app_loader import AppLoader
from .application import Application

__all__ = [
    "Application",
    "AppLoader",
    "AppConfig",
    "CoreUtil"
]



from ..engine.database_engine import DatabaseEngine as DatabaseEngine
from ..logger.logging_ import logging as logging
from _typeshed import Incomplete

class MetaConfigSetting:
    Registry: Incomplete
    RegistryModel: Incomplete
    EngineName: Incomplete
    RouterTags: Incomplete
    RouterPath: Incomplete
    SchemaName: Incomplete
    SchemaTable: Incomplete
    SchemaForeignKey: Incomplete
    AuthRole: Incomplete
    def __init__(
        self, *, engine_name, schema_name, router_path, router_tags, auth_role=None
    ) -> None: ...
    def add_router_path(self, router_path, table_or_view_name) -> None: ...
    def get_router_path(self, router_path): ...
    def remove_router_path(self, router_path) -> None: ...
    def clear_router_paths(self) -> None: ...



from ..meta.entity_class import EntityClass as EntityClass
from ..meta.service import GenericMetaService as GenericMetaService
from .generic_service import GenericService as GenericService

class GenericServiceV1(GenericService):
    @classmethod
    async def create(cls, *, schema_path, entity_path, create_models): ...
    @classmethod
    async def delete(cls, *, schema_path, entity_path, primary_id): ...
    @classmethod
    async def update(cls, *, schema_path, entity_path, primary_id, update_models): ...
    @classmethod
    async def read(cls, *, schema_path, entity_path, primary_id): ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/11/13 上午12:58
# @Desc     ：


from fastapi import Path
from sqlmodel.ext.asyncio.session import AsyncSession

from shudaodao_auth import AuthRouter
from shudaodao_core import Depends, ResponseUtil
from ..meta_config import MetaConfig
from ..tools.meta_store import MetaStore
from ..tools.source_store import SourceStore

Meta_Source_Router = AuthRouter(
    prefix=f"/{MetaConfig.RouterPath}",
    tags=["元数据管理 - 数据来源"],
    db_config_name=MetaConfig.EngineName,  # 配置文件中的数据库连接名称
    default_role="meta_admin",
    auth_role="admin"
)


@Meta_Source_Router.get(
    path="/sources/{sources_engine}/schemas/{schema_name}/discover", auth_role="admin",
    summary=["获取(不保存)数据库元数据"]
)
async def sources_discover(
        sources_engine: str = Path(description="数据库配置名称"),
        schema_name: str = Path(description="数据库模式(schema)"),
        *, db: AsyncSession = Depends(Meta_Source_Router.get_async_session)
):
    meta_store = SourceStore(db=db, engine_name=sources_engine, schema_name=schema_name)
    inspector_dict = meta_store.inspect()
    return ResponseUtil.success(message="获取元数据成功", data=inspector_dict)


@Meta_Source_Router.post(
    path="/sources/{sources_engine}/schemas/{schema_name}/sync", auth_role="admin",
    summary=["同步(获取+保存)元数据原始来源 - 从 数据库 database 同步到 原始来源"]
)
async def sources_sync(
        sources_engine: str = Path(description="数据库配置名称"),
        schema_name: str = Path(description="数据库模式(schema)"),
        *, db: AsyncSession = Depends(Meta_Source_Router.get_async_session)
):
    meta_store = SourceStore(db=db, engine_name=sources_engine, schema_name=schema_name)
    inspector_dict = meta_store.inspect()
    await meta_store.save_meta(metadata=inspector_dict)
    return ResponseUtil.success(message="同步成功", data=inspector_dict)


@Meta_Source_Router.post(
    path="/schemas/{schema_name}/sync", auth_role="admin",
    summary=["同步(获取+保存)元数据 - 从 原始来源 source 同步管理库"]
)
async def schemas_sync(
        schema_name: str = Path(description="数据库模式(schema)"),
        *, db: AsyncSession = Depends(Meta_Source_Router.get_async_session)
):
    sqlmodel_store = MetaStore(db=db, schema_name=schema_name)
    await sqlmodel_store.save_sqlmodel()
    return ResponseUtil.success(message="同步成功")



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/11/9 下午8:38
# @Desc     ：

from typing import Union, List

from fastapi import Path

from shudaodao_auth import AuthRouter
from shudaodao_core import QueryRequest
from shudaodao_meta.meta_config import MetaConfig
from ..services.generic_service_v2 import GenericServiceV2

generic_router = AuthRouter(
    prefix=f"/v2",
    db_config_name=MetaConfig.EngineName,
    tags=["通用接口 - 增删改查 v2 - 只支持 python"],
)


@generic_router.post(path="/{schema_path}/{entity_path}", summary="创建 schema - table/view 的数据，支持list")
async def create_route(
        create_models: Union[dict, List[dict]],
        schema_path: str = Path(description="数据库模式名称/别名"),
        entity_path: str = Path(description="数据库实体名称/别名"),
):
    return await GenericServiceV2.create(
        schema_path=schema_path, entity_path=entity_path,
        create_models=create_models,
    )


# @generic_router.patch(
#     path="/{schema_path}/{entity_path}", summary="更新 schema - table/view 的数据 支持list")
# async def update_route(
#         update_models: Union[dict, List[dict]],
#         schema_path: str = Path( description="数据库模式名称/别名"),
#         entity_path: str = Path( description="数据库实体名称/别名"),
# ):
#     entity_class: EntityClass = GenericMetaService().get_metadata(schema_path, entity_path)
#     update_model_list = await get_model_list(update_models, entity_class.update_class)
#     update_result = []
#     async with AsyncSessionService().get_session(entity_class.engine_name) as db:
#         for update_model in update_model_list:
#             update_result.append(await DataService.update(
#                 db,
#                 primary_id=getattr(update_model, entity_class.model_class.__primary_key__),
#                 model_class=entity_class.model_class,
#                 update_model=update_model,
#                 response_class=entity_class.response_class,
#             ))
#         result_len = len(update_result)
#         return ResponseUtil.success(
#             data=update_result[0] if result_len == 1 else update_result,
#             message="更新成功" if result_len == 1 else f"更新成功, 共{result_len}条"
#         )


@generic_router.post(path="/{schema_path}/{entity_path}/query", summary="查询 schema - table/view 的数据，支持关系查询")
async def query_route(
        query_request: QueryRequest,
        schema_path: str = Path(description="数据库模式名称/别名"),
        entity_path: str = Path(description="数据库实体名称/别名"),
):
    return await GenericServiceV2.query(
        schema_path=schema_path, entity_path=entity_path,
        query_request=query_request,
    )



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：Shudaodao Auto Generator
# @Software ：PyCharm
# @Desc     ：SQLModel classes for shudaodao_meta.meta_column

from datetime import datetime
from typing import Optional, TYPE_CHECKING

from sqlalchemy import BigInteger, Boolean

from shudaodao_core import SQLModel, BaseResponse, Field, Relationship, get_primary_id
from ...meta_config import MetaConfig

if TYPE_CHECKING:
    from .meta_table import MetaTable
    from .meta_view import MetaView


class MetaColumn(MetaConfig.RegistryModel, table=True):
    """数据库对象模型"""

    __tablename__ = "meta_column"
    __table_args__ = {"schema": MetaConfig.SchemaTable, "comment": "字段元数据"}
    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理

    meta_column_id: int = Field(
        default_factory=get_primary_id, primary_key=True, sa_type=BigInteger, description="主键"
    )
    meta_table_id: Optional[int] = Field(
        default=None,
        foreign_key=f"{MetaConfig.SchemaForeignKey}meta_table.meta_table_id",
        ondelete="CASCADE",
        sa_type=BigInteger,
        nullable=True,
        description="主键",
    )
    meta_view_id: Optional[int] = Field(
        default=None,
        foreign_key=f"{MetaConfig.SchemaForeignKey}meta_view.meta_view_id",
        ondelete="CASCADE",
        sa_type=BigInteger,
        nullable=True,
        description="主键",
    )
    name: str = Field(max_length=255, description="字段名")
    alias: Optional[str] = Field(default=None, nullable=True, max_length=255, description="字段别名")
    model_type: Optional[str] = Field(default=None, nullable=True, max_length=20, description="模型类型")
    is_primary: Optional[bool] = Field(default=None, sa_type=Boolean, nullable=True, description="主键字段")
    is_increment: Optional[bool] = Field(default=None, sa_type=Boolean, nullable=True, description="启用自增")
    is_unique: Optional[bool] = Field(default=None, sa_type=Boolean, nullable=True, description="单字段唯一")
    is_index: Optional[bool] = Field(default=None, sa_type=Boolean, nullable=True, description="单字段索引")
    py_type: str = Field(max_length=30, description="python类型")
    sa_type: str = Field(max_length=30, description="sqlalchemy类型")
    db_type: str = Field(max_length=20, description="database类型[仅用于展示]")
    nullable: bool = Field(sa_type=Boolean, description="是否可空")
    default: Optional[str] = Field(default=None, nullable=True, max_length=50, description="默认值(一般不用)")
    max_length: Optional[int] = Field(default=None, nullable=True, description="最大长度")
    precision: Optional[int] = Field(default=None, nullable=True, description="总位数")
    comment: Optional[str] = Field(default=None, nullable=True, max_length=255, description="字段说明")
    is_active: bool = Field(sa_type=Boolean, description="启用状态")
    scale: Optional[int] = Field(default=None, nullable=True, description="小数位数")
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(default=None, nullable=True, max_length=500, description="描述")
    create_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="创建人")
    create_at: Optional[datetime] = Field(default=None, nullable=True, description="创建日期")
    update_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="修改人")
    update_at: Optional[datetime] = Field(default=None, nullable=True, description="修改日期")
    # 反向关系 - 父对象
    MetaTable: "MetaTable" = Relationship(back_populates="MetaColumns")
    # 反向关系 - 父对象
    MetaView: "MetaView" = Relationship(back_populates="MetaColumns")


class MetaColumnCreate(SQLModel):
    """前端创建模型 - 用于接口请求"""

    meta_table_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="主键")
    meta_view_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="主键")
    name: str = Field(max_length=255, description="字段名")
    alias: Optional[str] = Field(default=None, max_length=255, description="字段别名")
    model_type: Optional[str] = Field(default=None, max_length=20, description="模型类型")
    is_primary: Optional[bool] = Field(default=None, description="主键字段")
    is_increment: Optional[bool] = Field(default=None, description="启用自增")
    is_unique: Optional[bool] = Field(default=None, description="单字段唯一")
    is_index: Optional[bool] = Field(default=None, description="单字段索引")
    py_type: str = Field(max_length=30, description="python类型")
    sa_type: str = Field(max_length=30, description="sqlalchemy类型")
    db_type: str = Field(max_length=20, description="database类型[仅用于展示]")
    nullable: bool = Field(description="是否可空")
    default: Optional[str] = Field(default=None, max_length=50, description="默认值(一般不用)")
    max_length: Optional[int] = Field(default=None, description="最大长度")
    precision: Optional[int] = Field(default=None, description="总位数")
    comment: Optional[str] = Field(default=None, max_length=255, description="字段说明")
    is_active: bool = Field(description="启用状态")
    scale: Optional[int] = Field(default=None, description="小数位数")
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class MetaColumnUpdate(SQLModel):
    """前端更新模型 - 用于接口请求"""

    meta_column_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="主键")
    meta_table_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="主键")
    meta_view_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="主键")
    name: Optional[str] = Field(default=None, max_length=255, description="字段名")
    alias: Optional[str] = Field(default=None, max_length=255, description="字段别名")
    model_type: Optional[str] = Field(default=None, max_length=20, description="模型类型")
    is_primary: Optional[bool] = Field(default=None, description="主键字段")
    is_increment: Optional[bool] = Field(default=None, description="启用自增")
    is_unique: Optional[bool] = Field(default=None, description="单字段唯一")
    is_index: Optional[bool] = Field(default=None, description="单字段索引")
    py_type: Optional[str] = Field(default=None, max_length=30, description="python类型")
    sa_type: Optional[str] = Field(default=None, max_length=30, description="sqlalchemy类型")
    db_type: Optional[str] = Field(default=None, max_length=20, description="database类型[仅用于展示]")
    nullable: Optional[bool] = Field(default=None, description="是否可空")
    default: Optional[str] = Field(default=None, max_length=50, description="默认值(一般不用)")
    max_length: Optional[int] = Field(default=None, description="最大长度")
    precision: Optional[int] = Field(default=None, description="总位数")
    comment: Optional[str] = Field(default=None, max_length=255, description="字段说明")
    is_active: Optional[bool] = Field(default=None, description="启用状态")
    scale: Optional[int] = Field(default=None, description="小数位数")
    sort_order: Optional[int] = Field(default=None, description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class MetaColumnResponse(BaseResponse):
    """前端响应模型 - 用于接口响应"""

    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
    meta_column_id: int = Field(description="主键", sa_type=BigInteger)
    meta_table_id: Optional[int] = Field(description="主键", default=None, sa_type=BigInteger)
    meta_view_id: Optional[int] = Field(description="主键", default=None, sa_type=BigInteger)
    name: str = Field(description="字段名")
    alias: Optional[str] = Field(description="字段别名", default=None)
    model_type: Optional[str] = Field(description="模型类型", default=None)
    is_primary: Optional[bool] = Field(description="主键字段", default=None)
    is_increment: Optional[bool] = Field(description="启用自增", default=None)
    is_unique: Optional[bool] = Field(description="单字段唯一", default=None)
    is_index: Optional[bool] = Field(description="单字段索引", default=None)
    py_type: str = Field(description="python类型")
    sa_type: str = Field(description="sqlalchemy类型")
    db_type: str = Field(description="database类型[仅用于展示]")
    nullable: bool = Field(description="是否可空")
    default: Optional[str] = Field(description="默认值(一般不用)", default=None)
    max_length: Optional[int] = Field(description="最大长度", default=None)
    precision: Optional[int] = Field(description="总位数", default=None)
    comment: Optional[str] = Field(description="字段说明", default=None)
    is_active: bool = Field(description="启用状态")
    scale: Optional[int] = Field(description="小数位数", default=None)
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(description="描述", default=None)
    create_by: Optional[str] = Field(description="创建人", default=None)
    create_at: Optional[datetime] = Field(description="创建日期", default=None)
    update_by: Optional[str] = Field(description="修改人", default=None)
    update_at: Optional[datetime] = Field(description="修改日期", default=None)



from ..generate.entity_table.meta_column import (
    MetaColumn as MetaColumn,
    MetaColumnCreate as MetaColumnCreate,
    MetaColumnUpdate as MetaColumnUpdate,
)
from ..generate.entity_table.meta_constraint import (
    MetaConstraint as MetaConstraint,
    MetaConstraintCreate as MetaConstraintCreate,
)
from ..generate.entity_table.meta_schema import MetaSchema as MetaSchema
from ..generate.entity_table.meta_table import (
    MetaTable as MetaTable,
    MetaTableCreate as MetaTableCreate,
    MetaTableUpdate as MetaTableUpdate,
)
from ..generate.entity_table.meta_view import (
    MetaView as MetaView,
    MetaViewCreate as MetaViewCreate,
    MetaViewUpdate as MetaViewUpdate,
)
from ..generate.entity_table.source_referencing_foreign_key import (
    SourceReferencingForeignKey as SourceReferencingForeignKey,
)
from ..generate.entity_table.source_schema import SourceSchema as SourceSchema
from .meta_convert import MetaConverter as MetaConverter
from shudaodao_core import AsyncSession as AsyncSession

class MetaStore:
    def __init__(self, *, db: AsyncSession = None, schema_name: str = None) -> None: ...
    async def save_sqlmodel(self, db: AsyncSession = None, schema_name: str = None): ...



from dataclasses import dataclass, field

@dataclass
class TemplateColumn:
    name: str
    comment: str
    is_primary_key: bool
    is_foreign_key: bool
    type: str
    clazz: str
    model_type: int
    params: list[str] = field(default_factory=list)

@dataclass
class TemplateClazz:
    schema_name: str
    table_name: str
    view_name: str
    comment: str
    file_name: str
    class_name: str
    table_args: str
    from_imports: list[str] = field(default_factory=list)
    database_columns: list[TemplateColumn] = field(default_factory=list)
    create_columns: list[TemplateColumn] = field(default_factory=list)
    update_columns: list[TemplateColumn] = field(default_factory=list)
    response_columns: list[TemplateColumn] = field(default_factory=list)
    relation_columns: list[TemplateColumn] = field(default_factory=list)



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：Shudaodao Auto Generator
# @Software ：PyCharm
# @Desc     ：SQLModel classes for shudaodao_meta.sys_enum_field

from datetime import datetime
from typing import Optional, TYPE_CHECKING

from sqlalchemy import BigInteger, Boolean

from shudaodao_core import SQLModel, BaseResponse, Field, Relationship, get_primary_id
from ...meta_config import MetaConfig

if TYPE_CHECKING:
    from .meta_schema import MetaSchema
    from .sys_enum_value import EnumValue


class EnumField(MetaConfig.RegistryModel, table=True):
    """数据库对象模型"""

    __tablename__ = "sys_enum_field"
    __table_args__ = {"schema": MetaConfig.SchemaTable, "comment": "枚举字段表"}
    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理

    field_id: int = Field(
        default_factory=get_primary_id, primary_key=True, sa_type=BigInteger, description="主键"
    )
    meta_schema_id: int = Field(
        foreign_key=f"{MetaConfig.SchemaForeignKey}meta_schema.meta_schema_id",
        sa_type=BigInteger,
        description="主键",
    )
    field_label: str = Field(max_length=50, description="字段标签")
    field_name: str = Field(max_length=50, description="字段列名")
    description: Optional[str] = Field(default=None, nullable=True, max_length=500, description="描述")
    is_active: bool = Field(sa_type=Boolean, description="启用状态")
    sort_order: int = Field(description="排序权重")
    create_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="创建人")
    create_at: Optional[datetime] = Field(default=None, nullable=True, description="创建日期")
    update_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="修改人")
    update_at: Optional[datetime] = Field(default=None, nullable=True, description="修改日期")
    tenant_id: Optional[int] = Field(default=None, sa_type=BigInteger, nullable=True, description="主键")
    # 反向关系 - 父对象
    MetaSchema: "MetaSchema" = Relationship(back_populates="EnumFields")
    # 正向关系 - 子对象
    EnumValues: list["EnumValue"] = Relationship(
        back_populates="EnumField", sa_relationship_kwargs={"order_by": "EnumValue.sort_order.asc()"}
    )


class EnumFieldCreate(SQLModel):
    """前端创建模型 - 用于接口请求"""

    meta_schema_id: int = Field(sa_type=BigInteger, description="主键")
    field_label: str = Field(max_length=50, description="字段标签")
    field_name: str = Field(max_length=50, description="字段列名")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")
    is_active: bool = Field(description="启用状态")
    sort_order: int = Field(description="排序权重")


class EnumFieldUpdate(SQLModel):
    """前端更新模型 - 用于接口请求"""

    field_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="主键")
    meta_schema_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="主键")
    field_label: Optional[str] = Field(default=None, max_length=50, description="字段标签")
    field_name: Optional[str] = Field(default=None, max_length=50, description="字段列名")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")
    is_active: Optional[bool] = Field(default=None, description="启用状态")
    sort_order: Optional[int] = Field(default=None, description="排序权重")


class EnumFieldResponse(BaseResponse):
    """前端响应模型 - 用于接口响应"""

    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
    field_id: int = Field(description="主键", sa_type=BigInteger)
    meta_schema_id: int = Field(description="主键", sa_type=BigInteger)
    field_label: str = Field(description="字段标签")
    field_name: str = Field(description="字段列名")
    description: Optional[str] = Field(description="描述", default=None)
    is_active: bool = Field(description="启用状态")
    sort_order: int = Field(description="排序权重")
    create_by: Optional[str] = Field(description="创建人", default=None)
    create_at: Optional[datetime] = Field(description="创建日期", default=None)
    update_by: Optional[str] = Field(description="修改人", default=None)
    update_at: Optional[datetime] = Field(description="修改日期", default=None)



from .clazz_int import EnumInt as EnumInt
from .clazz_str import EnumStr as EnumStr
from typing import Any

class EnumManager:
    def __new__(cls):
        """线程安全的单例构造器"""
    def get_field_names(self, model_class): ...
    def register(self, schema_name: str, enum_dict: dict[str, Any]):
        """注册枚举值"""
    def is_enum_field(self, schema_name: str, field_name) -> bool: ...
    def resolve_value(self, model_class, field_name: str, value) -> dict[str, Any]:
        """获取枚举值"""
    def clear(self) -> None: ...
    def __del__(self) -> None: ...



#!/usr/bin/env python3
# # -*- coding:utf-8 -*-
# # @License  ：(C)Copyright 2025, 数道智融科技
# # @Author   ：Shudaodao Auto Generator
# # @Software ：PyCharm
# # @Desc     ：SQLModel classes for shudaodao_auth.t_auth_rule
# 
# from typing import Optional
# 
# from shudaodao_core import SQLModel, BaseResponse, Field, get_primary_id
# from ...meta_config import MetaConfig
# 
# 
# class AuthRule(MetaConfig.RegistryModel, table=True):
#     """数据库对象模型"""
# 
#     __tablename__ = "t_auth_rule"
#     __table_args__ = {"schema": MetaConfig.SchemaTable, "comment": "访问控制规则表"}
#     __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
# 
#     id: int = Field(
#         default=None, primary_key=True, sa_column_kwargs={"autoincrement": True}, description="主键"
#     )
#     ptype: Optional[str] = Field(default=None, nullable=True, max_length=255, description="类型")
#     v0: Optional[str] = Field(default=None, nullable=True, max_length=255, description="角色/用户")
#     v1: Optional[str] = Field(default=None, nullable=True, max_length=255, description="资源/角色")
#     v2: Optional[str] = Field(default=None, nullable=True, max_length=255, description="动作")
#     v3: Optional[str] = Field(default=None, nullable=True, max_length=255, description="租户")
#     v4: Optional[str] = Field(default=None, nullable=True, max_length=255)
#     v5: Optional[str] = Field(default=None, nullable=True, max_length=255)
# 
# 
# class AuthRuleCreate(SQLModel):
#     """前端创建模型 - 用于接口请求"""
# 
#     ptype: Optional[str] = Field(default=None, max_length=255, description="类型")
#     v0: Optional[str] = Field(default=None, max_length=255, description="角色/用户")
#     v1: Optional[str] = Field(default=None, max_length=255, description="资源/角色")
#     v2: Optional[str] = Field(default=None, max_length=255, description="动作")
#     v3: Optional[str] = Field(default=None, max_length=255, description="租户")
#     v4: Optional[str] = Field(default=None, max_length=255)
#     v5: Optional[str] = Field(default=None, max_length=255)
# 
# 
# class AuthRuleUpdate(SQLModel):
#     """前端更新模型 - 用于接口请求"""
# 
#     id: Optional[int] = Field(default=None, description="主键")
#     ptype: Optional[str] = Field(default=None, max_length=255, description="类型")
#     v0: Optional[str] = Field(default=None, max_length=255, description="角色/用户")
#     v1: Optional[str] = Field(default=None, max_length=255, description="资源/角色")
#     v2: Optional[str] = Field(default=None, max_length=255, description="动作")
#     v3: Optional[str] = Field(default=None, max_length=255, description="租户")
#     v4: Optional[str] = Field(default=None, max_length=255)
#     v5: Optional[str] = Field(default=None, max_length=255)
# 
# 
# class AuthRuleResponse(BaseResponse):
#     """前端响应模型 - 用于接口响应"""
# 
#     __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
#     id: int = Field(description="主键")
#     ptype: Optional[str] = Field(description="类型", default=None)
#     v0: Optional[str] = Field(description="角色/用户", default=None)
#     v1: Optional[str] = Field(description="资源/角色", default=None)
#     v2: Optional[str] = Field(description="动作", default=None)
#     v3: Optional[str] = Field(description="租户", default=None)
#     v4: Optional[str] = Field(default=None)
#     v5: Optional[str] = Field(default=None)
# 



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：Shudaodao Auto Generator
# @Software ：PyCharm
# @Desc     ：SQLModel classes for shudaodao_enum.sys_enum_schema

from datetime import datetime
from typing import Optional, TYPE_CHECKING

from sqlalchemy import BigInteger, Boolean

from shudaodao_core import Field, get_primary_id, Relationship
from shudaodao_core import SQLModel, BaseResponse
from ... import RegistryModel, get_table_schema

if TYPE_CHECKING:
    from .sys_enum_field import EnumField


class EnumSchema(RegistryModel, table=True):
    """ 数据库对象模型 """
    __tablename__ = "sys_enum_schema"
    __table_args__ = {"schema": get_table_schema(), "comment": "模式(schema)"}
    # 非数据库字段：仅用于内部处理
    __database_schema__ = "shudaodao_enum"
    # 数据库字段
    schema_id: int = Field(
        default_factory=get_primary_id, primary_key=True, sa_type=BigInteger, description="主键ID"
    )
    schema_label: str = Field(max_length=100, description="模式别名")
    schema_name: str = Field(max_length=100, description="模式(schema)")
    is_active: bool = Field(sa_type=Boolean, description="启用状态")
    sort_order: int = Field(default=10, description="排序权重")
    create_by: Optional[str] = Field(default=None, max_length=50, nullable=True, description="创建人")
    create_at: Optional[datetime] = Field(
        default_factory=lambda: datetime.now().replace(microsecond=0), nullable=True, description="创建日期"
    )
    update_by: Optional[str] = Field(default=None, max_length=50, nullable=True, description="修改人")
    update_at: Optional[datetime] = Field(
        default_factory=lambda: datetime.now().replace(microsecond=0), nullable=True, description="修改日期"
    )
    tenant_id: Optional[int] = Field(default=None, nullable=True, sa_type=BigInteger, description="主键")
    # 正向关系 -> 子对象
    EnumFields: list["EnumField"] = Relationship(
        back_populates="Schema", sa_relationship_kwargs={
            "order_by": "EnumField.sort_order.asc()"
        }
    )


class EnumSchemaBase(SQLModel):
    """ 创建、更新模型 共用字段 """
    schema_label: str = Field(max_length=100, description="模式别名")
    schema_name: str = Field(max_length=100, description="模式(schema)")
    is_active: bool = Field(description="启用状态")
    sort_order: int = Field(default=10, description="排序权重")


class EnumSchemaCreate(EnumSchemaBase):
    """ 前端创建模型 - 用于接口请求 """
    ...


class EnumSchemaUpdate(EnumSchemaBase):
    """ 前端更新模型 - 用于接口请求 """
    ...


class EnumSchemaResponse(BaseResponse):
    """ 前端响应模型 - 用于接口响应 """
    __database_schema__ = "shudaodao_enum"  # 仅用于内部处理

    schema_id: int = Field(description="主键ID", sa_type=BigInteger)
    schema_label: str = Field(description="模式别名")
    schema_name: str = Field(description="模式(schema)")
    is_active: bool = Field(description="启用状态")
    sort_order: int = Field(description="排序权重")
    create_by: Optional[str] = Field(description="创建人", default=None)
    create_at: Optional[datetime] = Field(description="创建日期", default=None)
    update_by: Optional[str] = Field(description="修改人", default=None)
    update_at: Optional[datetime] = Field(description="修改日期", default=None)



from ..generate.entity_table.source_column import SourceColumn as SourceColumn
from ..generate.entity_table.source_foreign_key import (
    SourceForeignKey as SourceForeignKey,
)
from ..generate.entity_table.source_index import SourceIndex as SourceIndex
from ..generate.entity_table.source_primary_key import (
    SourcePrimaryKey as SourcePrimaryKey,
)
from ..generate.entity_table.source_referencing_foreign_key import (
    SourceReferencingForeignKey as SourceReferencingForeignKey,
)
from ..generate.entity_table.source_schema import SourceSchema as SourceSchema
from ..generate.entity_table.source_table import SourceTable as SourceTable
from ..generate.entity_table.source_view import SourceView as SourceView
from .meta_convert import MetaConverter as MetaConverter
from .source_inspect import SourceInspect as SourceInspect
from shudaodao_core import AsyncSession as AsyncSession

class SourceStore:
    auto_commit: bool
    def __init__(
        self,
        *,
        db: AsyncSession = None,
        engine_name: str = None,
        schema_name: str = None,
    ) -> None: ...
    def inspect(self, *, engine_name: str = None, schema_name: str = None) -> dict: ...
    async def save_meta(
        self,
        *,
        metadata: dict = None,
        db: AsyncSession = None,
        engine_name: str = None,
        schema_name: str = None,
    ): ...



from ..generate.entity_table.meta_table import MetaTable as MetaTable
from ..generate.entity_table.meta_view import MetaView as MetaView
from .meta_convert import MetaConverter as MetaConverter
from .meta_query import MetaQuery as MetaQuery
from .template_clazz import (
    TemplateClazz as TemplateClazz,
    TemplateColumn as TemplateColumn,
)
from shudaodao_core import AsyncSession as AsyncSession

class MetaTemplate:
    def __init__(self, db: AsyncSession = None) -> None: ...
    @classmethod
    def format_column(cls, column: TemplateColumn) -> str: ...
    async def render_schema(self, schema_name: str): ...
    async def render_view(self, schema_name: str, view_name: str, files: list[str]): ...
    async def render_table(
        self, schema_name: str, table_name: str, files: list[str]
    ): ...
    @staticmethod
    def comment_vue_file(file_path) -> None: ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：Shudaodao Auto Generator
# @Software ：PyCharm
# @Desc     ：SQLModel classes for shudaodao_meta.source_view

from datetime import datetime
from typing import Optional, TYPE_CHECKING

from sqlalchemy import BigInteger, Text

from shudaodao_core import SQLModel, BaseResponse, Field, Relationship, get_primary_id
from ...meta_config import MetaConfig

if TYPE_CHECKING:
    from .source_column import SourceColumn
    from .source_schema import SourceSchema


class SourceView(MetaConfig.RegistryModel, table=True):
    """数据库对象模型"""

    __tablename__ = "source_view"
    __table_args__ = {"schema": MetaConfig.SchemaTable, "comment": "视图元数据"}
    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理

    source_view_id: int = Field(
        default_factory=get_primary_id, primary_key=True, sa_type=BigInteger, description="主键"
    )
    source_schema_id: int = Field(
        foreign_key=f"{MetaConfig.SchemaForeignKey}source_schema.source_schema_id",
        ondelete="CASCADE",
        sa_type=BigInteger,
        description="主键",
    )
    view_name: str = Field(max_length=255, description="视图名字")
    definition: Optional[str] = Field(default=None, sa_type=Text, nullable=True, description="SQL脚本")
    class_name: Optional[str] = Field(default=None, nullable=True, max_length=50, description="类名")
    file_name: Optional[str] = Field(default=None, nullable=True, max_length=50, description="文件名")
    comment: Optional[str] = Field(default=None, sa_type=Text, nullable=True, description="备注")
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(default=None, nullable=True, max_length=500, description="描述")
    create_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="创建人")
    create_at: Optional[datetime] = Field(default=None, nullable=True, description="创建日期")
    update_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="修改人")
    update_at: Optional[datetime] = Field(default=None, nullable=True, description="修改日期")
    # 反向关系 - 父对象
    SourceSchema: "SourceSchema" = Relationship(back_populates="SourceViews")
    # 正向关系 - 子对象
    SourceColumns: list["SourceColumn"] = Relationship(
        back_populates="SourceView", sa_relationship_kwargs={"order_by": "SourceColumn.sort_order.asc()"}
    )


class SourceViewCreate(SQLModel):
    """前端创建模型 - 用于接口请求"""

    source_schema_id: int = Field(sa_type=BigInteger, description="主键")
    view_name: str = Field(max_length=255, description="视图名字")
    definition: Optional[str] = Field(default=None, description="SQL脚本")
    class_name: Optional[str] = Field(default=None, max_length=50, description="类名")
    file_name: Optional[str] = Field(default=None, max_length=50, description="文件名")
    comment: Optional[str] = Field(default=None, description="备注")
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class SourceViewUpdate(SQLModel):
    """前端更新模型 - 用于接口请求"""

    source_view_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="主键")
    source_schema_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="主键")
    view_name: Optional[str] = Field(default=None, max_length=255, description="视图名字")
    definition: Optional[str] = Field(default=None, description="SQL脚本")
    class_name: Optional[str] = Field(default=None, max_length=50, description="类名")
    file_name: Optional[str] = Field(default=None, max_length=50, description="文件名")
    comment: Optional[str] = Field(default=None, description="备注")
    sort_order: Optional[int] = Field(default=None, description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class SourceViewResponse(BaseResponse):
    """前端响应模型 - 用于接口响应"""

    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
    source_view_id: int = Field(description="主键", sa_type=BigInteger)
    source_schema_id: int = Field(description="主键", sa_type=BigInteger)
    view_name: str = Field(description="视图名字")
    definition: Optional[str] = Field(description="SQL脚本", default=None)
    class_name: Optional[str] = Field(description="类名", default=None)
    file_name: Optional[str] = Field(description="文件名", default=None)
    comment: Optional[str] = Field(description="备注", default=None)
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(description="描述", default=None)
    create_by: Optional[str] = Field(description="创建人", default=None)
    create_at: Optional[datetime] = Field(description="创建日期", default=None)
    update_by: Optional[str] = Field(description="修改人", default=None)
    update_at: Optional[datetime] = Field(description="修改日期", default=None)



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：Shudaodao Auto Generator
# @Software ：PyCharm
# @Desc     ：SQLModel classes for shudaodao_meta.meta_schema

from datetime import datetime
from typing import Optional, TYPE_CHECKING

from sqlalchemy import BigInteger

from shudaodao_core import SQLModel, BaseResponse, Field, Relationship, get_primary_id
from ...meta_config import MetaConfig

if TYPE_CHECKING:
    from .meta_table import MetaTable
    from .meta_view import MetaView
    from .sys_enum_field import EnumField


class MetaSchema(MetaConfig.RegistryModel, table=True):
    """数据库对象模型"""

    __tablename__ = "meta_schema"
    __table_args__ = {"schema": MetaConfig.SchemaTable, "comment": "代码元数据"}
    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理

    meta_schema_id: int = Field(
        default_factory=get_primary_id, primary_key=True, sa_type=BigInteger, description="主键"
    )
    schema_label: Optional[str] = Field(
        default=None, nullable=True, max_length=128, description="数据库-模式标签"
    )
    schema_name: str = Field(max_length=128, description="数据库-模式(schema)")
    engine_name: Optional[str] = Field(
        default=None, nullable=True, max_length=128, description="数据库-配置名称"
    )
    router_name: Optional[str] = Field(
        default=None, nullable=True, max_length=128, description="API路由-路径名称"
    )
    router_tags: Optional[str] = Field(
        default=None, nullable=True, max_length=256, description="API路由-分组标签"
    )
    output_frontend: Optional[str] = Field(
        default=None, nullable=True, max_length=256, description="前端路径"
    )
    output_backend: Optional[str] = Field(default=None, nullable=True, max_length=256, description="后端路径")
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(default=None, nullable=True, max_length=500, description="描述")
    create_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="创建人")
    create_at: Optional[datetime] = Field(default=None, nullable=True, description="创建日期")
    update_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="修改人")
    update_at: Optional[datetime] = Field(default=None, nullable=True, description="修改日期")
    # 正向关系 - 子对象
    MetaTables: list["MetaTable"] = Relationship(
        back_populates="MetaSchema", sa_relationship_kwargs={"order_by": "MetaTable.sort_order.asc()"}
    )
    # 正向关系 - 子对象
    MetaViews: list["MetaView"] = Relationship(
        back_populates="MetaSchema", sa_relationship_kwargs={"order_by": "MetaView.sort_order.asc()"}
    )
    # 正向关系 - 子对象
    EnumFields: list["EnumField"] = Relationship(
        back_populates="MetaSchema", sa_relationship_kwargs={"order_by": "EnumField.sort_order.asc()"}
    )


class MetaSchemaCreate(SQLModel):
    """前端创建模型 - 用于接口请求"""

    schema_label: Optional[str] = Field(default=None, max_length=128, description="数据库-模式标签")
    schema_name: str = Field(max_length=128, description="数据库-模式(schema)")
    engine_name: Optional[str] = Field(default=None, max_length=128, description="数据库-配置名称")
    router_name: Optional[str] = Field(default=None, max_length=128, description="API路由-路径名称")
    router_tags: Optional[str] = Field(default=None, max_length=256, description="API路由-分组标签")
    output_frontend: Optional[str] = Field(default=None, max_length=256, description="前端路径")
    output_backend: Optional[str] = Field(default=None, max_length=256, description="后端路径")
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class MetaSchemaUpdate(SQLModel):
    """前端更新模型 - 用于接口请求"""

    meta_schema_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="主键")
    schema_label: Optional[str] = Field(default=None, max_length=128, description="数据库-模式标签")
    schema_name: Optional[str] = Field(default=None, max_length=128, description="数据库-模式(schema)")
    engine_name: Optional[str] = Field(default=None, max_length=128, description="数据库-配置名称")
    router_name: Optional[str] = Field(default=None, max_length=128, description="API路由-路径名称")
    router_tags: Optional[str] = Field(default=None, max_length=256, description="API路由-分组标签")
    output_frontend: Optional[str] = Field(default=None, max_length=256, description="前端路径")
    output_backend: Optional[str] = Field(default=None, max_length=256, description="后端路径")
    sort_order: Optional[int] = Field(default=None, description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class MetaSchemaResponse(BaseResponse):
    """前端响应模型 - 用于接口响应"""

    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
    meta_schema_id: int = Field(description="主键", sa_type=BigInteger)
    schema_label: Optional[str] = Field(description="数据库-模式标签", default=None)
    schema_name: str = Field(description="数据库-模式(schema)")
    engine_name: Optional[str] = Field(description="数据库-配置名称", default=None)
    router_name: Optional[str] = Field(description="API路由-路径名称", default=None)
    router_tags: Optional[str] = Field(description="API路由-分组标签", default=None)
    output_frontend: Optional[str] = Field(description="前端路径", default=None)
    output_backend: Optional[str] = Field(description="后端路径", default=None)
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(description="描述", default=None)
    create_by: Optional[str] = Field(description="创建人", default=None)
    create_at: Optional[datetime] = Field(description="创建日期", default=None)
    update_by: Optional[str] = Field(description="修改人", default=None)
    update_at: Optional[datetime] = Field(description="修改日期", default=None)



from ..entity_table.t_auth_user import (
    AuthUser as AuthUser,
    AuthUserResponse as AuthUserResponse,
)
from ..services.casbin_service import PermissionService as PermissionService
from _typeshed import Incomplete
from fastapi import Request as Request
from fastapi.security import (
    HTTPAuthorizationCredentials as HTTPAuthorizationCredentials,
)
from sqlmodel.ext.asyncio.session import AsyncSession as AsyncSession

class AuthService:
    """认证服务类，处理用户认证、密码验证、JWT令牌管理等操作"""

    TOKEN_SECRET_KEY: Incomplete
    TOKEN_ALGORITHM: str
    TOKEN_EXPIRE_MINUTES: Incomplete
    TOKEN_REFRESH_EXPIRE_DAYS: Incomplete
    http_bearer: Incomplete
    @classmethod
    def verify_password(cls, plain_password: str, hashed_password: str) -> bool:
        """验证明文密码与哈希密码是否匹配。"""
    @classmethod
    def hash_password(cls, password: str) -> str:
        """对明文密码进行哈希处理。"""
    @classmethod
    def jwt_encode(cls, data: dict) -> str:
        """编码数据生成JWT令牌。

        Args:
            data: 需要编码到令牌中的数据

        Returns:
            str: 编码后的JWT令牌字符串
        """
    @classmethod
    def jwt_decode(cls, token) -> dict:
        """解码JWT令牌获取原始数据。

        Args:
            token: JWT令牌字符串

        Returns:
            dict: 解码后的令牌数据

        Raises:
            AuthError: 当令牌无效或已过期时
        """
    @classmethod
    def get_permission(cls):
        """获取权限服务实例。

        Returns:
            PermissionService: 权限服务实例
        """
    @classmethod
    async def get_current_user_request(
        cls, request: Request, db: AsyncSession = ...
    ): ...
    @classmethod
    async def get_current_user(
        cls, auth_bearer: HTTPAuthorizationCredentials = ..., db: AsyncSession = ...
    ): ...
    @classmethod
    async def logout(cls) -> None:
        """用户登出操作。

        Note:
            此功能尚未实现
        """
    @classmethod
    async def refresh(cls, refresh_token, db: AsyncSession):
        """刷新访问令牌。

        Note:
            此功能尚未实现

        Returns:
            待实现的刷新令牌功能
        """
    @classmethod
    async def login(cls, *, db: AsyncSession, auth_login):
        """用户登录认证。

        Args:
            db: 数据库会话
            auth_login: 登录请求数据模型

        Returns:
            str: JWT访问令牌

        Raises:
            LoginException: 当用户名密码错误、账户未激活或其他登录错误时
        """
    @classmethod
    async def modify_password(cls, db: AsyncSession, *, password_model, current_user):
        """修改用户密码。

        Args:
            db: 数据库会话
            password_model: 密码修改数据模型
            current_user: 当前用户信息

        Raises:
            AuthException: 当原始密码不正确或密码修改失败时
        """



from shudaodao_core import AsyncSession as AsyncSession

class EnumService:
    @classmethod
    async def initialize(cls, db: AsyncSession): ...
    @classmethod
    async def clear(cls) -> None: ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：Shudaodao Auto Generator
# @Software ：PyCharm
# @Desc     ：SQLModel classes for shudaodao_acm.sys_staff_role

from datetime import datetime
from typing import Optional, TYPE_CHECKING

from sqlalchemy import BigInteger

from shudaodao_core import SQLModel, BaseResponse, Field, Relationship, get_primary_id
from ...meta_config import MetaConfig

if TYPE_CHECKING:
    from .sys_staff import Staff


class StaffRole(MetaConfig.RegistryModel, table=True):
    """数据库对象模型"""

    __tablename__ = "sys_staff_role"
    __table_args__ = {"schema": MetaConfig.SchemaTable}
    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理

    staff_role_id: int = Field(
        default_factory=get_primary_id, primary_key=True, sa_type=BigInteger, description="人员角色关系内码"
    )
    role_id: int = Field(sa_type=BigInteger, description="角色内码")
    staff_id: int = Field(
        foreign_key=f"{MetaConfig.SchemaForeignKey}sys_staff.staff_id",
        sa_type=BigInteger,
        description="人员内码",
    )
    expiry_at: Optional[datetime] = Field(default=None, nullable=True, description="过期时间")
    create_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="创建人")
    create_at: Optional[datetime] = Field(default=None, nullable=True, description="创建日期")
    update_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="修改人")
    update_at: Optional[datetime] = Field(default=None, nullable=True, description="修改日期")
    tenant_id: Optional[int] = Field(default=None, sa_type=BigInteger, nullable=True, description="租户内码")
    # 反向关系 - 父对象
    Staff: "Staff" = Relationship(back_populates="StaffRoles")


class StaffRoleCreate(SQLModel):
    """前端创建模型 - 用于接口请求"""

    role_id: int = Field(sa_type=BigInteger, description="角色内码")
    staff_id: int = Field(sa_type=BigInteger, description="人员内码")
    expiry_at: Optional[datetime] = Field(default=None, description="过期时间")


class StaffRoleUpdate(SQLModel):
    """前端更新模型 - 用于接口请求"""

    staff_role_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="人员角色关系内码")
    role_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="角色内码")
    staff_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="人员内码")
    expiry_at: Optional[datetime] = Field(default=None, description="过期时间")


class StaffRoleResponse(BaseResponse):
    """前端响应模型 - 用于接口响应"""

    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
    staff_role_id: int = Field(description="人员角色关系内码", sa_type=BigInteger)
    role_id: int = Field(description="角色内码", sa_type=BigInteger)
    staff_id: int = Field(description="人员内码", sa_type=BigInteger)
    expiry_at: Optional[datetime] = Field(description="过期时间", default=None)
    create_by: Optional[str] = Field(description="创建人", default=None)
    create_at: Optional[datetime] = Field(description="创建日期", default=None)
    update_by: Optional[str] = Field(description="修改人", default=None)
    update_at: Optional[datetime] = Field(description="修改日期", default=None)



from ..generate.entity_table.meta_schema import MetaSchema as MetaSchema
from ..generate.entity_table.meta_table import MetaTable as MetaTable
from ..generate.entity_table.meta_view import MetaView as MetaView
from shudaodao_core import AsyncSession as AsyncSession

class MetaQuery:
    @classmethod
    async def get_schema(cls, db: AsyncSession, schema_name: str) -> MetaSchema: ...
    @classmethod
    async def get_tables_views_by_schema_name(
        cls, db: AsyncSession, schema_name: str, is_active: bool = None
    ): ...
    @classmethod
    async def query_metatable(
        cls, db: AsyncSession, schema_name: str, table_name: str, is_active: bool = None
    ): ...
    @classmethod
    async def query_metaview(
        cls, db: AsyncSession, schema_name: str, view_name: str, is_active: bool = None
    ): ...



#!/usr/bin/env python3
# # -*- coding:utf-8 -*-
# # @License  ：(C)Copyright 2025, 数道智融科技
# # @Author   ：Shudaodao Auto Generator
# # @Software ：PyCharm
# # @Desc     ：SQLModel classes for shudaodao_auth.t_auth_user
# 
# from datetime import datetime
# from typing import Optional
# 
# from sqlalchemy import BigInteger, Boolean
# 
# from shudaodao_core import SQLModel, BaseResponse, Field, get_primary_id
# from ...meta_config import MetaConfig
# 
# 
# class AuthUser(MetaConfig.RegistryModel, table=True):
#     """数据库对象模型"""
# 
#     __tablename__ = "t_auth_user"
#     __table_args__ = {"schema": MetaConfig.SchemaTable, "comment": "鉴权账户"}
#     __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
# 
#     user_id: int = Field(
#         default_factory=get_primary_id, primary_key=True, sa_type=BigInteger, description="主键"
#     )
#     username: str = Field(max_length=50, unique=True, index=True, description="账户名")
#     name: Optional[str] = Field(default=None, nullable=True, description="姓名")
#     password: str = Field(description="密码")
#     is_active: bool = Field(sa_type=Boolean, description="启用状态")
#     last_login_at: Optional[datetime] = Field(default=None, nullable=True, description="最后登录时间")
#     nickname: Optional[str] = Field(default=None, nullable=True, description="昵称")
#     picture: Optional[str] = Field(default=None, nullable=True, description="头像URL地址")
#     email: Optional[str] = Field(default=None, nullable=True, description="邮件")
#     email_verified: Optional[bool] = Field(
#         default=None, sa_type=Boolean, nullable=True, description="邮箱是否已验证"
#     )
#     totp_verified: Optional[bool] = Field(
#         default=None, sa_type=Boolean, nullable=True, description="启用身份验证器"
#     )
#     create_by: Optional[str] = Field(default=None, nullable=True, description="创建人")
#     create_at: Optional[datetime] = Field(default=None, nullable=True, description="创建日期")
#     update_by: Optional[str] = Field(default=None, nullable=True, description="修改人")
#     update_at: Optional[datetime] = Field(default=None, nullable=True, description="修改日期")
#     tenant_id: Optional[int] = Field(default=None, sa_type=BigInteger, nullable=True, description="默认租户")
#     staff_id: Optional[int] = Field(default=None, sa_type=BigInteger, nullable=True, description="默认用户")
# 
# 
# class AuthUserCreate(SQLModel):
#     """前端创建模型 - 用于接口请求"""
# 
#     username: str = Field(max_length=50, description="账户名")
#     name: Optional[str] = Field(default=None, description="姓名")
#     password: str = Field(description="密码")
#     is_active: bool = Field(description="启用状态")
#     last_login_at: Optional[datetime] = Field(default=None, description="最后登录时间")
#     nickname: Optional[str] = Field(default=None, description="昵称")
#     picture: Optional[str] = Field(default=None, description="头像URL地址")
#     email: Optional[str] = Field(default=None, description="邮件")
#     email_verified: Optional[bool] = Field(default=None, description="邮箱是否已验证")
#     totp_verified: Optional[bool] = Field(default=None, description="启用身份验证器")
#     staff_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="默认用户")
# 
# 
# class AuthUserUpdate(SQLModel):
#     """前端更新模型 - 用于接口请求"""
# 
#     user_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="主键")
#     username: Optional[str] = Field(default=None, max_length=50, description="账户名")
#     name: Optional[str] = Field(default=None, description="姓名")
#     password: Optional[str] = Field(default=None, description="密码")
#     is_active: Optional[bool] = Field(default=None, description="启用状态")
#     last_login_at: Optional[datetime] = Field(default=None, description="最后登录时间")
#     nickname: Optional[str] = Field(default=None, description="昵称")
#     picture: Optional[str] = Field(default=None, description="头像URL地址")
#     email: Optional[str] = Field(default=None, description="邮件")
#     email_verified: Optional[bool] = Field(default=None, description="邮箱是否已验证")
#     totp_verified: Optional[bool] = Field(default=None, description="启用身份验证器")
#     staff_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="默认用户")
# 
# 
# class AuthUserResponse(BaseResponse):
#     """前端响应模型 - 用于接口响应"""
# 
#     __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
#     user_id: int = Field(description="主键", sa_type=BigInteger)
#     username: str = Field(description="账户名")
#     name: Optional[str] = Field(description="姓名", default=None)
#     password: str = Field(description="密码")
#     is_active: bool = Field(description="启用状态")
#     last_login_at: Optional[datetime] = Field(description="最后登录时间", default=None)
#     nickname: Optional[str] = Field(description="昵称", default=None)
#     picture: Optional[str] = Field(description="头像URL地址", default=None)
#     email: Optional[str] = Field(description="邮件", default=None)
#     email_verified: Optional[bool] = Field(description="邮箱是否已验证", default=None)
#     totp_verified: Optional[bool] = Field(description="启用身份验证器", default=None)
#     create_by: Optional[str] = Field(description="创建人", default=None)
#     create_at: Optional[datetime] = Field(description="创建日期", default=None)
#     update_by: Optional[str] = Field(description="修改人", default=None)
#     update_at: Optional[datetime] = Field(description="修改日期", default=None)
#     staff_id: Optional[int] = Field(description="默认用户", default=None, sa_type=BigInteger)
# 



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/8/18 下午7:43
# @Desc     ：
from datetime import datetime, date, time
from typing import Any, Dict
from typing import Optional

from pydantic import Field, BaseModel
from sqlalchemy import BigInteger
from sqlmodel import SQLModel

from ..enums.manager import EnumManager
from ..utils.core_utils import CoreUtil


class BaseResponse(SQLModel):
    """
    支持 sa_type=BigInteger 转 字符串
    支持 日期格式化
    支持 枚举转化，新增字段 key_label
    支持嵌套模型递归转换
    """

    def model_dump(self, *args, **kwargs) -> Dict[str, Any]:
        # 先获取原始 dump 结果（不包含嵌套模型的转换）
        data = super().model_dump(*args, **kwargs)

        # 遍历所有字段定义
        for field_name, field_info in self.model_fields.items():
            # value = data.get(field_name)  # 从原始数据字典获取 无法进行实例判断
            value = getattr(self, field_name)  # 从模型实例获取 才能判断类型
            if value is None:
                continue

            # 1. BigInteger → str  雪花算法ID
            if hasattr(field_info, 'sa_type') and field_info.sa_type is BigInteger:
                data[field_name] = str(value)
            # 2. datetime → ISO 8601 字符串
            elif isinstance(value, datetime):
                data[field_name] = CoreUtil.format_datatime(value.isoformat())
            # 3. date → YYYY-MM-DD
            elif isinstance(value, date):
                data[field_name] = value.isoformat()  # "2025-09-22"
            # 4. time → HH:MM:SS
            elif isinstance(value, time):
                data[field_name] = value.isoformat()  # "10:30:00"
            # 5. BaseReadModel 实例 → 递归转换
            elif isinstance(value, BaseResponse):
                dump_value = value.model_dump(*args, **kwargs)
                data[field_name] = self.base_response_format_enum(value.__class__, dump_value)
            # 6. 字段是列表，且元素是 BaseReadModel → 递归转换每个元素
            elif isinstance(value, list):
                rows = []
                for item in value:
                    if isinstance(item, BaseResponse):
                        dump_value = item.model_dump(*args, **kwargs)
                        rows.append(self.base_response_format_enum(item.__class__, dump_value))
                    else:
                        rows.append(item)
                data[field_name] = rows
        return data

    @staticmethod
    def base_response_format_enum(model_class, dump_value):
        # 获取枚举字段
        enum_fields = EnumManager().get_field_names(model_class)
        if not enum_fields:
            return dump_value

        enum_dict = {}
        for key, val in dump_value.items():
            enum_dict[key] = val
            if key not in enum_fields:
                continue
            # 处理枚举
            enum_dict[key + "_label"] = EnumManager().resolve_value(model_class, key, val)
        return enum_dict

    # 兼容 Pydantic v1 / jsonable_encoder
    def dict(self, *args, **kwargs) -> Dict[str, Any]:
        return self.model_dump(*args, **kwargs)


class SuccessResponse(BaseResponse):
    code: int = Field(200, description="Response code")
    msg: str = ""
    data: Optional[Any] = None


class ErrorResponse(BaseModel):
    code: int = Field(..., description="Response code")
    msg: str = ""
    error: Optional[Any] = None


class TokenResponse(BaseModel):
    token_type: str = "Bearer"
    access_token: str
    expires_in: int

    refresh_token: Optional[str] = None
    refresh_expires_in: int
    # scope: Optional[str] = None # 暂时用不上

    # user: Dict[str, Any]  # 暂时用不上
    # Art Design Pro
    token: str
    # id_token: Optional[str] = None  # 暂时用不上


# class TokenErrorResponse(BaseModel):
#     error: str
#     error_description: str
#     error_code: Optional[str] = None
#     timestamp: str = Field(default_factory=lambda: datetime.now().timestamp())


class TokenRefreshModel(BaseModel):
    refresh_token: str



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：Shudaodao Auto Generator
# @Software ：PyCharm
# @Desc     ：SQLModel classes for shudaodao_acm.sys_department

from datetime import datetime
from typing import Optional, TYPE_CHECKING

from sqlalchemy import BigInteger

from shudaodao_core import SQLModel, BaseResponse, Field, Relationship, get_primary_id
from ...meta_config import MetaConfig

if TYPE_CHECKING:
    from .sys_staff import Staff


class Department(MetaConfig.RegistryModel, table=True):
    """数据库对象模型"""

    __tablename__ = "sys_department"
    __table_args__ = {"schema": MetaConfig.SchemaTable}
    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理

    department_id: int = Field(
        default_factory=get_primary_id, primary_key=True, sa_type=BigInteger, description="部门ID"
    )
    department_pid: int = Field(sa_type=BigInteger, description="父部门ID")
    name: str = Field(max_length=100, description="部门名称")
    sort_order: Optional[int] = Field(default=None, nullable=True, description="排序权重")
    description: Optional[str] = Field(default=None, nullable=True, max_length=500, description="描述")
    create_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="创建人")
    create_at: Optional[datetime] = Field(default=None, nullable=True, description="创建日期")
    update_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="修改人")
    update_at: Optional[datetime] = Field(default=None, nullable=True, description="修改日期")
    tenant_id: Optional[int] = Field(default=None, sa_type=BigInteger, nullable=True, description="租户内码")
    # 正向关系 - 子对象
    Staffs: list["Staff"] = Relationship(
        back_populates="Department", sa_relationship_kwargs={"order_by": "Staff.sort_order.asc()"}
    )


class DepartmentCreate(SQLModel):
    """前端创建模型 - 用于接口请求"""

    department_pid: int = Field(sa_type=BigInteger, description="父部门ID")
    name: str = Field(max_length=100, description="部门名称")
    sort_order: Optional[int] = Field(default=None, description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class DepartmentUpdate(SQLModel):
    """前端更新模型 - 用于接口请求"""

    department_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="部门ID")
    department_pid: Optional[int] = Field(default=None, sa_type=BigInteger, description="父部门ID")
    name: Optional[str] = Field(default=None, max_length=100, description="部门名称")
    sort_order: Optional[int] = Field(default=None, description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class DepartmentResponse(BaseResponse):
    """前端响应模型 - 用于接口响应"""

    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
    department_id: int = Field(description="部门ID", sa_type=BigInteger)
    department_pid: int = Field(description="父部门ID", sa_type=BigInteger)
    name: str = Field(description="部门名称")
    sort_order: Optional[int] = Field(description="排序权重", default=None)
    description: Optional[str] = Field(description="描述", default=None)
    create_by: Optional[str] = Field(description="创建人", default=None)
    create_at: Optional[datetime] = Field(description="创建日期", default=None)
    update_by: Optional[str] = Field(description="修改人", default=None)
    update_at: Optional[datetime] = Field(description="修改日期", default=None)



async def check_metadata_to_database(source_metadata, engine_name):
    """在开发环境下自动同步数据库表结构"""

async def check_admin_user() -> None:
    """在开发环境下检查并创建默认管理员账户。
    遍历 AppConfig.auth.default_admin_users 中定义的用户名，
    若数据库中不存在，则使用用户名作为密码（明文哈希后）创建新用户。
    仅在 AppConfig.environment.model == "dev" 时执行。
    """



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：Shudaodao Auto Generator
# @Software ：PyCharm
# @Desc     ：SQLModel classes for shudaodao_meta.meta_web_api

from typing import Optional, TYPE_CHECKING

from sqlalchemy import BigInteger

from shudaodao_core import SQLModel, BaseResponse, Field, Relationship, get_primary_id
from ...meta_config import MetaConfig

if TYPE_CHECKING:
    from .meta_table import MetaTable
    from .meta_view import MetaView


class MetaWebApi(MetaConfig.RegistryModel, table=True):
    """数据库对象模型"""

    __tablename__ = "meta_web_api"
    __table_args__ = {"schema": MetaConfig.SchemaTable, "comment": "API接口"}
    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理

    meta_web_api_id: int = Field(default_factory=get_primary_id, primary_key=True, sa_type=BigInteger)
    meta_table_id: Optional[int] = Field(
        default=None,
        foreign_key=f"{MetaConfig.SchemaForeignKey}meta_table.meta_table_id",
        ondelete="CASCADE",
        sa_type=BigInteger,
        nullable=True,
    )
    meta_view_id: Optional[int] = Field(
        default=None,
        foreign_key=f"{MetaConfig.SchemaForeignKey}meta_view.meta_view_id",
        ondelete="CASCADE",
        sa_type=BigInteger,
        nullable=True,
    )
    web_api_name: Optional[str] = Field(default=None, nullable=True, max_length=128, description="接口名称")
    router_path: Optional[int] = Field(default=None, nullable=True, description="路由路径")
    # 反向关系 - 父对象
    MetaTable: "MetaTable" = Relationship(back_populates="MetaWebApis")
    # 反向关系 - 父对象
    MetaView: "MetaView" = Relationship(back_populates="MetaWebApis")


class MetaWebApiCreate(SQLModel):
    """前端创建模型 - 用于接口请求"""

    meta_table_id: Optional[int] = Field(default=None, sa_type=BigInteger)
    meta_view_id: Optional[int] = Field(default=None, sa_type=BigInteger)
    web_api_name: Optional[str] = Field(default=None, max_length=128, description="接口名称")
    router_path: Optional[int] = Field(default=None, description="路由路径")


class MetaWebApiUpdate(SQLModel):
    """前端更新模型 - 用于接口请求"""

    meta_web_api_id: Optional[int] = Field(default=None, sa_type=BigInteger)
    meta_table_id: Optional[int] = Field(default=None, sa_type=BigInteger)
    meta_view_id: Optional[int] = Field(default=None, sa_type=BigInteger)
    web_api_name: Optional[str] = Field(default=None, max_length=128, description="接口名称")
    router_path: Optional[int] = Field(default=None, description="路由路径")


class MetaWebApiResponse(BaseResponse):
    """前端响应模型 - 用于接口响应"""

    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
    meta_web_api_id: int = Field(sa_type=BigInteger)
    meta_table_id: Optional[int] = Field(default=None, sa_type=BigInteger)
    meta_view_id: Optional[int] = Field(default=None, sa_type=BigInteger)
    web_api_name: Optional[str] = Field(description="接口名称", default=None)
    router_path: Optional[int] = Field(description="路由路径", default=None)



from ..exception.service_exception import (
    PermError as PermError,
    ValidError as ValidError,
)
from ..tools.tenant_user_info import (
    TenantUserInfo as TenantUserInfo,
    get_tenant_user_info as get_tenant_user_info,
    set_tenant_user_info as set_tenant_user_info,
)

class TenantManager:
    @classmethod
    def disable(cls) -> None: ...
    @classmethod
    def set(cls, *, username, tenant_id) -> None: ...
    @classmethod
    def set_from_token(cls, *, username, tenant_id, tenant_enabled=None) -> None: ...
    @classmethod
    def apply_tenant_condition(cls, *, db_model, conditions): ...
    @classmethod
    def get_tenant_condition(cls, *, db_model): ...
    @classmethod
    def set_field_with_user_and_tenant(cls, db_model) -> None: ...
    @classmethod
    def check_permission(cls, db_model) -> None: ...



from ..meta.entity_class import EntityClass as EntityClass
from shudaodao_core import AsyncSession as AsyncSession

class GenericMetaService:
    def __new__(cls): ...
    async def initialize(self, db: AsyncSession = None): ...
    def get_metadata(self, schema_path, entity_path): ...
    def close(self) -> None: ...
    def __del__(self) -> None: ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/11/3 上午2:01

from .auth.auth_router import AuthRouter
from .engine.casbin_engine import PermissionEngine
from .services.auth_service import AuthService
from .services.casbin_service import PermissionService



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/10/25 下午6:42
# @Desc     ：


from fastapi import Path
from sqlmodel.ext.asyncio.session import AsyncSession

from shudaodao_auth import AuthRouter
from shudaodao_core import Depends, ResponseUtil
from ..meta_config import MetaConfig
from ..tools.meta_template import MetaTemplate

Meta_Generate_Router = AuthRouter(
    prefix=f"/{MetaConfig.RouterPath}",
    tags=["元数据管理 - 生成代码"],
    db_config_name=MetaConfig.EngineName,  # 配置文件中的数据库连接名称
)


@Meta_Generate_Router.post(
    path="/schemas/{schema_name}/tables/{table_name}/generate", auth_role="admin",
    summary=["生成 schema - table 代码"]
)
async def schemas_tables_generate(
        schema_name: str = Path(description="数据库模式(schema)"),
        table_name: str = Path(description="表名"),
        *, db: AsyncSession = Depends(Meta_Generate_Router.get_async_session)
):
    tmpl = MetaTemplate(db=db)
    data = await tmpl.render_table(schema_name, table_name, [])
    return ResponseUtil.success(message=f"生成表 {table_name} 代码成功", data=data)


@Meta_Generate_Router.post(
    path="/schemas/{schema_name}/views/{view_name}/generate", auth_role="admin",
    summary=["生成 schema - view 代码"]
)
async def schemas_views_generate(
        schema_name: str = Path(description="数据库模式(schema)"),
        view_name: str = Path(description="视图名"),
        *, db: AsyncSession = Depends(Meta_Generate_Router.get_async_session)
):
    tmpl = MetaTemplate(db=db)
    data = await tmpl.render_view(schema_name, view_name, [""])
    return ResponseUtil.success(message=f"生成视图 {view_name} 代码成功", data=data)


@Meta_Generate_Router.post(
    path="/schemas/{schema_name}/generate", auth_role="admin",
    summary=["生成 schema - 全部代码"]
)
async def schemas_views_generate(
        schema_name: str = Path(description="数据库模式(schema)"),
        *, db: AsyncSession = Depends(Meta_Generate_Router.get_async_session)
):
    tmpl = MetaTemplate(db=db)
    data = await tmpl.render_schema(schema_name)
    return ResponseUtil.success(message="生成模式代码成功", data=data)



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：Shudaodao Auto Generator
# @Software ：PyCharm
# @Desc     ：SQLModel classes for shudaodao_acm.sys_permission

from datetime import datetime
from typing import Optional, TYPE_CHECKING

from sqlalchemy import BigInteger, Boolean

from shudaodao_core import SQLModel, BaseResponse, Field, Relationship, get_primary_id
from ...meta_config import MetaConfig

if TYPE_CHECKING:
    from .sys_module import Module
    from .sys_system import System


class Permission(MetaConfig.RegistryModel, table=True):
    """数据库对象模型"""

    __tablename__ = "sys_permission"
    __table_args__ = {"schema": MetaConfig.SchemaTable, "comment": "功能模块"}
    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理

    permission_id: int = Field(
        default_factory=get_primary_id, primary_key=True, sa_type=BigInteger, description="模块内码"
    )
    system_id: int = Field(
        foreign_key=f"{MetaConfig.SchemaForeignKey}sys_system.system_id",
        sa_type=BigInteger,
        description="模块内码",
    )
    module_id: int = Field(
        foreign_key=f"{MetaConfig.SchemaForeignKey}sys_module.module_id",
        sa_type=BigInteger,
        description="模块内码",
    )
    permission_name: Optional[str] = Field(
        default=None, nullable=True, max_length=100, description="权限名称"
    )
    permission_type: Optional[str] = Field(default=None, nullable=True, max_length=20, description="权限类型")
    permission_code: Optional[str] = Field(default=None, nullable=True, max_length=50, description="权限编码")
    page_active: Optional[bool] = Field(default=None, sa_type=Boolean, nullable=True, description="页面启用")
    element_active: Optional[bool] = Field(
        default=None, sa_type=Boolean, nullable=True, description="元素可见"
    )
    api_active: Optional[bool] = Field(default=None, sa_type=Boolean, nullable=True, description="接口启用")
    api_method: Optional[str] = Field(default=None, nullable=True, max_length=200, description="api方法")
    api_url: Optional[str] = Field(default=None, nullable=True, max_length=200, description="api地址")
    api_role: Optional[str] = Field(default=None, nullable=True, max_length=200, description="api验证角色")
    api_obj: Optional[str] = Field(default=None, nullable=True, max_length=200, description="api对象")
    api_act: Optional[str] = Field(default=None, nullable=True, max_length=200, description="api动作")
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(default=None, nullable=True, max_length=500, description="描述")
    create_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="创建账户")
    create_at: Optional[datetime] = Field(default=None, nullable=True, description="创建日期")
    update_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="修改账户")
    update_at: Optional[datetime] = Field(default=None, nullable=True, description="修改日期")
    tenant_id: Optional[int] = Field(default=None, sa_type=BigInteger, nullable=True, description="租户内码")
    # 反向关系 - 父对象
    Module: "Module" = Relationship(back_populates="Permissions")
    # 反向关系 - 父对象
    System: "System" = Relationship(back_populates="Permissions")


class PermissionCreate(SQLModel):
    """前端创建模型 - 用于接口请求"""

    system_id: int = Field(sa_type=BigInteger, description="模块内码")
    module_id: int = Field(sa_type=BigInteger, description="模块内码")
    permission_name: Optional[str] = Field(default=None, max_length=100, description="权限名称")
    permission_type: Optional[str] = Field(default=None, max_length=20, description="权限类型")
    permission_code: Optional[str] = Field(default=None, max_length=50, description="权限编码")
    page_active: Optional[bool] = Field(default=None, description="页面启用")
    element_active: Optional[bool] = Field(default=None, description="元素可见")
    api_active: Optional[bool] = Field(default=None, description="接口启用")
    api_method: Optional[str] = Field(default=None, max_length=200, description="api方法")
    api_url: Optional[str] = Field(default=None, max_length=200, description="api地址")
    api_role: Optional[str] = Field(default=None, max_length=200, description="api验证角色")
    api_obj: Optional[str] = Field(default=None, max_length=200, description="api对象")
    api_act: Optional[str] = Field(default=None, max_length=200, description="api动作")
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class PermissionUpdate(SQLModel):
    """前端更新模型 - 用于接口请求"""

    permission_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="模块内码")
    system_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="模块内码")
    module_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="模块内码")
    permission_name: Optional[str] = Field(default=None, max_length=100, description="权限名称")
    permission_type: Optional[str] = Field(default=None, max_length=20, description="权限类型")
    permission_code: Optional[str] = Field(default=None, max_length=50, description="权限编码")
    page_active: Optional[bool] = Field(default=None, description="页面启用")
    element_active: Optional[bool] = Field(default=None, description="元素可见")
    api_active: Optional[bool] = Field(default=None, description="接口启用")
    api_method: Optional[str] = Field(default=None, max_length=200, description="api方法")
    api_url: Optional[str] = Field(default=None, max_length=200, description="api地址")
    api_role: Optional[str] = Field(default=None, max_length=200, description="api验证角色")
    api_obj: Optional[str] = Field(default=None, max_length=200, description="api对象")
    api_act: Optional[str] = Field(default=None, max_length=200, description="api动作")
    sort_order: Optional[int] = Field(default=None, description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class PermissionResponse(BaseResponse):
    """前端响应模型 - 用于接口响应"""

    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
    permission_id: int = Field(description="模块内码", sa_type=BigInteger)
    system_id: int = Field(description="模块内码", sa_type=BigInteger)
    module_id: int = Field(description="模块内码", sa_type=BigInteger)
    permission_name: Optional[str] = Field(description="权限名称", default=None)
    permission_type: Optional[str] = Field(description="权限类型", default=None)
    permission_code: Optional[str] = Field(description="权限编码", default=None)
    page_active: Optional[bool] = Field(description="页面启用", default=None)
    element_active: Optional[bool] = Field(description="元素可见", default=None)
    api_active: Optional[bool] = Field(description="接口启用", default=None)
    api_method: Optional[str] = Field(description="api方法", default=None)
    api_url: Optional[str] = Field(description="api地址", default=None)
    api_role: Optional[str] = Field(description="api验证角色", default=None)
    api_obj: Optional[str] = Field(description="api对象", default=None)
    api_act: Optional[str] = Field(description="api动作", default=None)
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(description="描述", default=None)
    create_by: Optional[str] = Field(description="创建账户", default=None)
    create_at: Optional[datetime] = Field(description="创建日期", default=None)
    update_by: Optional[str] = Field(description="修改账户", default=None)
    update_at: Optional[datetime] = Field(description="修改日期", default=None)



from ..auth.auth_router import AuthRouter as AuthRouter
from ..entity_table.t_auth_user import (
    AuthLogin as AuthLogin,
    AuthPassword as AuthPassword,
    AuthUser as AuthUser,
    AuthUserRegister as AuthUserRegister,
    AuthUserResponse as AuthUserResponse,
)
from ..meta_config import MetaConfig as MetaConfig
from ..services.auth_service import AuthService as AuthService
from _typeshed import Incomplete
from fastapi.security import OAuth2PasswordRequestForm as OAuth2PasswordRequestForm
from shudaodao_core.schemas.response import TokenRefreshModel as TokenRefreshModel
from sqlmodel.ext.asyncio.session import AsyncSession as AsyncSession

Auth_Controller: Incomplete

async def auth_register(register_model: AuthUserRegister, db: AsyncSession = ...): ...
async def auth_login(login_model: AuthLogin, db: AsyncSession = ...): ...
async def auth_token(
    form_data: OAuth2PasswordRequestForm = ..., db: AsyncSession = ...
): ...
async def auth_refresh(refresh_model: TokenRefreshModel, db: AsyncSession = ...): ...
async def auth_logout(): ...
async def auth_me_password(
    password_model: AuthPassword,
    db: AsyncSession = ...,
    current_user: AuthUserResponse = ...,
): ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：Shudaodao Auto Generator
# @Software ：PyCharm
# @Desc     ：SQLModel classes for shudaodao_meta.source_schema

from datetime import datetime
from typing import Optional, TYPE_CHECKING

from sqlalchemy import BigInteger

from shudaodao_core import SQLModel, BaseResponse, Field, Relationship, get_primary_id
from ...meta_config import MetaConfig

if TYPE_CHECKING:
    from .source_referencing_foreign_key import SourceReferencingForeignKey
    from .source_table import SourceTable
    from .source_view import SourceView


class SourceSchema(MetaConfig.RegistryModel, table=True):
    """数据库对象模型"""

    __tablename__ = "source_schema"
    __table_args__ = {"schema": MetaConfig.SchemaTable, "comment": "模式(schema)"}
    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理

    source_schema_id: int = Field(
        default_factory=get_primary_id, primary_key=True, sa_type=BigInteger, description="主键"
    )
    schema_label: Optional[str] = Field(default=None, nullable=True, max_length=128, description="架构中文")
    schema_name: str = Field(max_length=128, description="数据库模式")
    engine_name: str = Field(max_length=128, description="数据引擎名")
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(default=None, nullable=True, max_length=500, description="描述")
    create_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="创建人")
    create_at: Optional[datetime] = Field(default=None, nullable=True, description="创建日期")
    update_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="修改人")
    update_at: Optional[datetime] = Field(default=None, nullable=True, description="修改日期")
    # 正向关系 - 子对象
    SourceReferencingForeignKeys: list["SourceReferencingForeignKey"] = Relationship(
        back_populates="SourceSchema",
        sa_relationship_kwargs={"order_by": "SourceReferencingForeignKey.sort_order.asc()"},
    )
    # 正向关系 - 子对象
    SourceTables: list["SourceTable"] = Relationship(
        back_populates="SourceSchema", sa_relationship_kwargs={"order_by": "SourceTable.sort_order.asc()"}
    )
    # 正向关系 - 子对象
    SourceViews: list["SourceView"] = Relationship(
        back_populates="SourceSchema", sa_relationship_kwargs={"order_by": "SourceView.sort_order.asc()"}
    )


class SourceSchemaCreate(SQLModel):
    """前端创建模型 - 用于接口请求"""

    schema_label: Optional[str] = Field(default=None, max_length=128, description="架构中文")
    schema_name: str = Field(max_length=128, description="数据库模式")
    engine_name: str = Field(max_length=128, description="数据引擎名")
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class SourceSchemaUpdate(SQLModel):
    """前端更新模型 - 用于接口请求"""

    source_schema_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="主键")
    schema_label: Optional[str] = Field(default=None, max_length=128, description="架构中文")
    schema_name: Optional[str] = Field(default=None, max_length=128, description="数据库模式")
    engine_name: Optional[str] = Field(default=None, max_length=128, description="数据引擎名")
    sort_order: Optional[int] = Field(default=None, description="排序权重")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")


class SourceSchemaResponse(BaseResponse):
    """前端响应模型 - 用于接口响应"""

    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
    source_schema_id: int = Field(description="主键", sa_type=BigInteger)
    schema_label: Optional[str] = Field(description="架构中文", default=None)
    schema_name: str = Field(description="数据库模式")
    engine_name: str = Field(description="数据引擎名")
    sort_order: int = Field(description="排序权重")
    description: Optional[str] = Field(description="描述", default=None)
    create_by: Optional[str] = Field(description="创建人", default=None)
    create_at: Optional[datetime] = Field(description="创建日期", default=None)
    update_by: Optional[str] = Field(description="修改人", default=None)
    update_at: Optional[datetime] = Field(description="修改日期", default=None)



from ..meta.entity_class import EntityClass as EntityClass
from ..meta.service import GenericMetaService as GenericMetaService
from .generic_service import GenericService as GenericService

class GenericServiceV2(GenericService):
    @classmethod
    async def create(cls, create_models, entity_path, schema_path): ...
    @classmethod
    async def query(cls, *, schema_path, entity_path, query_request): ...



from .template_clazz import TemplateColumn as TemplateColumn
from _typeshed import Incomplete

class MetaConverter:
    irregular_plurals: Incomplete
    special_endings: Incomplete
    case_mapping: Incomplete
    model_type_mapping: Incomplete
    @staticmethod
    def set_update_property(data_model, meta_model): ...
    @staticmethod
    def get_file_name(table_or_view_name: str) -> str: ...
    @classmethod
    def get_camel_name(cls, table_or_view_name: str) -> str:
        """（驼峰命名，去除前缀 t/v/sys）"""
    @staticmethod
    def dump_json(data): ...
    @classmethod
    def set_column_type(cls, column_name): ...
    @classmethod
    def is_primary(cls, column_name, constrained_columns): ...
    @classmethod
    def is_unique(cls, column_name, meta_indexes): ...
    @classmethod
    def get_plural_name(cls, column_name) -> str:
        """将名称转换为复数形式  注意：这是一个简单的规则实现，可能不适用于所有情况"""
    @staticmethod
    def get_sqlalchemy_type(db_type: str) -> str:
        """将数据库类型映射到 SQLAlchemy 类型"""
    @classmethod
    def get_from_import(cls, meta_model, is_view: bool = False): ...
    @classmethod
    def get_database_columns(cls, meta_model, foreign_fields): ...
    @classmethod
    def get_response_columns(cls, meta_model, foreign_fields): ...
    @classmethod
    def get_create_columns(cls, meta_model, foreign_fields): ...
    @classmethod
    def get_update_columns(cls, meta_model, foreign_fields): ...
    @classmethod
    def get_relation_columns(cls, meta_model): ...
    @classmethod
    def get_table_args(cls, meta_model, is_view: bool = False): ...
